@@ -32,19 +32,19 @@
 /** default chromosome */
 struct chromosome_t thisChromosome = (struct chromosome_t) {
 	{
-	 {1.371242, 1.984368, 1.336144, 1.111876, 1.206090, 0.052862,
-	  1.506242, 1.684672},
-	 /* weight of every resource, value of Development Card, relative value of City (compared to equivalen Settlement) and Ports, when I have 0 Victory Points */
-	 {1.262966, 1.813653, 1.542921, 1.117926, 1.338699, 3.004164, 1.682371, 3.554963},	/* when I have 1 */
-	 {1.770271, 1.405915, 1.947900, 1.267916, 1.645481, 0.266591, 1.194223, 9.644183},	/* 2 */
-	 {1.371931, 1.962052, 1.071650, 1.335991, 1.076773, 3.367637, 1.703712, 6.706741},	/* 3 */
-	 {1.680568, 1.306249, 1.743218, 1.761761, 1.025129, 1.121913, 0.284101, 1.559953},	/* 4 */
-	 {1.674057, 1.994260, 1.067930, 1.046954, 1.594052, 3.381377, 0.250717, 4.673997},	/* 5 */
-	 {1.116162, 1.225133, 1.141381, 1.093680, 1.976306, 3.066351, 0.672955, 9.152541},	/* 6 */
-	 {1.402262, 1.515350, 1.835050, 1.781056, 1.091004, 4.470943, 0.112013, 9.202737},	/* 7 */
-	 {1.009420, 1.065439, 1.938907, 1.966596, 1.279951, 0.777970, 1.659520, 3.782044},	/* 8 */
-	 {1.828237, 1.597190, 1.909004, 1.690179, 1.643655, 2.087759, 1.848852, 2.809332},	/* 9 */
-	 },
+	 /* weight of every resource, value of Development Card, relative value of City 
+	    (compared to equivalen Settlement) and Ports, when I have X Victory Points */
+	 { 1.371242, 1.984368, 1.336144, 1.111876, 1.206090, 0.052862, 1.506242, 1.684672},	/* 0 */
+	 { 1.262966, 1.813653, 1.542921, 1.117926, 1.338699, 3.004164, 1.682371, 3.554963},	/* 1 */
+	 { 1.770271, 1.405915, 1.947900, 1.267916, 1.645481, 0.266591, 1.194223, 9.644183},	/* 2 */
+	 { 1.371931, 1.962052, 1.071650, 1.335991, 1.076773, 3.367637, 1.703712, 6.706741},	/* 3 */
+	 { 1.680568, 1.306249, 1.743218, 1.761761, 1.025129, 1.121913, 0.284101, 1.559953},	/* 4 */
+	 { 1.674057, 1.994260, 1.067930, 1.046954, 1.594052, 3.381377, 0.250717, 4.673997},	/* 5 */
+	 { 1.116162, 1.225133, 1.141381, 1.093680, 1.976306, 3.066351, 0.672955, 9.152541},	/* 6 */
+	 { 1.402262, 1.515350, 1.835050, 1.781056, 1.091004, 4.470943, 0.112013, 9.202737},	/* 7 */
+	 { 1.009420, 1.065439, 1.938907, 1.966596, 1.279951, 0.777970, 1.659520, 3.782044},	/* 8 */
+	 { 1.828237, 1.597190, 1.909004, 1.690179, 1.643655, 2.087759, 1.848852, 2.809332},	/* 9 */
+	  },
 	1.714336, 0.580583, 0.265190	/* depreciation, turn and probability */
 };
 
@@ -591,7 +591,7 @@ static int facingOK(const Node * node, Hex * hex)
 
 
 
-/* It returns the value given to an hex surrounding a node. We also need to know the node to check (for maritime hexes) if it has acces to the port */
+/* It returns the value given to an hex surrounding a node. We also need to know the node to check (for maritime hexes) if it has access to the port */
 static float genetic_score_hex(const Node * node, Hex * hex,
 			       const struct chromosome_t *myChromosome,
 			       const struct gameState_t *myGameState)
@@ -615,7 +615,7 @@ static float genetic_score_hex(const Node * node, Hex * hex,
 	/* I want to decrease the devaluation the hex resource suffers (increase the hex value) if a I have a generic port or a specific port to export that resource */
 	if (info.any_resource)
 		port = 3;	/* I have a generic port, depreciation will be less */
-	else if (info.specific_resource[resrc])
+	else if (resrc < NO_RESOURCE && info.specific_resource[resrc])
 		port = 2;	/* I have a port to export this resource, depreciation will be even less */
 	nodeHasPort = facingOK(node, hex);
 	if (resrc < NO_RESOURCE) {
@@ -1975,8 +1975,8 @@ static void genetic_turn(void)
 			   else if ((destinationLongRoadScore)&&(destinationLongRoadScore>destinationRoadScore)) {
 			   cb_build_road(long_road_edge);
 			   return;
-			   }
-			   break; */
+			   } */
+			break;
 		case RSET:
 			if (destinationRoadScore) {
 				printf
@@ -2266,7 +2266,7 @@ static float monopoly_wildcard_value(const resource_values_t * resval,
 /** Determine the best resource to get with a monopoly card.
  * @return the resource
 */
-static gint determine_monopoly_resource()
+static gint determine_monopoly_resource(void)
 {
 	gint assets[NO_RESOURCE];
 	int i;
