@@ -50,26 +50,31 @@ static float strategyProfit(float time_a, float time_b, float turn,
 			    int num_players);
 
 static int resourcesNeededForAction[NUM_ACTIONS][5] = {
-	/*Resources of every type needed to perform every action possible */
-	{1, 1, 0, 1, 1}, /*SET*/ {0, 2, 3, 0, 0}, /*CIT*/ {0, 1, 1, 1, 0}, /*DEV*/ {2, 1, 0, 1, 2}, /*RSET*/ {3, 1, 0, 1, 3}, /*RRSET*/ {2, 2, 0, 2, 2},	/*SET+SET */
-	{1, 3, 3, 1, 1},	/*SET+CIT */
-	{1, 2, 1, 2, 1},	/*SET+DEV */
-	{3, 2, 0, 2, 3},	/*SET+RSET */
-	{4, 2, 0, 2, 4},	/*SET+RRSET */
+/*Resources of every type needed to perform every action possible */
+	{ 1, 1, 0, 1, 1 },	/*SET */
+	{ 0, 2, 3, 0, 0 },	/*CIT */
+	{ 0, 1, 1, 1, 0 },	/*DEV */
+	{ 2, 1, 0, 1, 2 },	/*RSET */
+	{ 3, 1, 0, 1, 3 },	/*RRSET */
+	{ 2, 2, 0, 2, 2 },	/*SET+SET */
+	{ 1, 3, 3, 1, 1 },	/*SET+CIT */
+	{ 1, 2, 1, 2, 1 },	/*SET+DEV */
+	{ 3, 2, 0, 2, 3 },	/*SET+RSET */
+	{ 4, 2, 0, 2, 4 },	/*SET+RRSET */
 
-	{0, 4, 6, 0, 0},	/*CIT+CIT */
-	{0, 3, 4, 1, 0},	/*CIT+DEV */
-	{2, 3, 3, 1, 2},	/*CIT+RSET */
-	{3, 3, 3, 1, 3},	/*CIT+RRSET */
+	{ 0, 4, 6, 0, 0 },	/*CIT+CIT */
+	{ 0, 3, 4, 1, 0 },	/*CIT+DEV */
+	{ 2, 3, 3, 1, 2 },	/*CIT+RSET */
+	{ 3, 3, 3, 1, 3 },	/*CIT+RRSET */
 
-	{0, 2, 2, 2, 0},	/*DEV+DEV */
-	{2, 2, 1, 2, 2},	/*DEV+RSET */
-	{3, 2, 1, 2, 3},	/*DEV+RRSET */
+	{ 0, 2, 2, 2, 0 },	/*DEV+DEV */
+	{ 2, 2, 1, 2, 2 },	/*DEV+RSET */
+	{ 3, 2, 1, 2, 3 },	/*DEV+RRSET */
 
-	{4, 2, 0, 2, 4},	/*RSET+RSET */
-	{5, 2, 0, 2, 5},	/*RSET+RRSET */
+	{ 4, 2, 0, 2, 4 },	/*RSET+RSET */
+	{ 5, 2, 0, 2, 5 },	/*RSET+RRSET */
 
-	{6, 2, 0, 2, 6}		/*RRSET+RRSET */
+	{ 6, 2, 0, 2, 6 }	/*RRSET+RRSET */
 };				/*First index is the action, second index the kind of resource */
 
 int totalResources(const struct gameState_t *myGameState)
@@ -273,7 +278,7 @@ void updateConditionsMet(float probability, struct simulationsData_t *Data)
 	for (sim = 0; sim < MAX_SIMS; sim++) {
 		updateSimulation(sim, probability, Data);
 	}
-	/*At this point numberOfSimulationsOK will hold, for avery action, the number of simulations that, up to the turn calculated, meet the requirements to do it */
+	/*At this point numberOfSimulationsOK will hold, for every action, the number of simulations that, up to the turn calculated, meet the requirements to do it */
 }
 
 void updateTurnsToAction(float probability, int currentTurn,
@@ -291,7 +296,7 @@ void updateTurnsToAction(float probability, int currentTurn,
 
 #if 0
 
-/*This should ne rewriten in orden to take acount of the order change in resources (Now it should go Br,Gr,Or,Wo and Lu)*/
+/*This should be rewritten in order to take account of the order change in resources (Now it should go Br,Gr,Or,Wo and Lu)*/
 
 void outputSims(int number, int turn, struct simulationsData_t *Data)
 {
@@ -449,7 +454,7 @@ float strategyProfit(float time_a, float time_b, float turn,
 		     int num_players)
 {
 	/*Returns the benefit I get in a given turn if I try to do firstAction ending at time_a and then secondAction ending at time_b
-	 * time_a, time_b and turn should be possitive numbers, turn>=0, time_b>=time_a>=0*/
+	 * time_a, time_b and turn should be positive numbers, turn>=0, time_b>=time_a>=0*/
 	float profit;
 	float firstActionValue = myGameState.actionValue[oneStrategy[0]];
 	float secondActionValue = myGameState.actionValue[oneStrategy[1]];
@@ -460,7 +465,7 @@ float strategyProfit(float time_a, float time_b, float turn,
 	int roadsWillBuild;
 	if (firstActionValue == 0)
 		return 0;	/*It is impossible to do first action (not enough tokens, no place for it, etc.), so this strategy is worthless */
-	/*If this strategy requires doing nothing now, the amount of resources I finsh the turn with can decrease this strategy value depending on the risk of being affected by the thief */
+	/*If this strategy requires doing nothing now, the amount of resources I finish the turn with can decrease this strategy value depending on the risk of being affected by the thief */
 	if ((time_a != 0) && (myTurn)) {	/*I am waiting to do something, will I finish my turn with a "risky" amount of resources? */
 		endOfTurnResources = totalResources(&myGameState);
 		roadsWillBuild =
@@ -622,6 +627,7 @@ int checkRoadNow(enum action firstAction, enum action secondAction,
 			return (roadsPossible);
 			break;
 		}
+		return 0;
 	case RSET:
 		/*Even if I can do two roads now, I should not use the resources I will need for the settlement of RSET */
 		return (1);
