@@ -95,7 +95,7 @@ StateMachine *SM(void)
 
 /* When commands are sent to the server, front ends may want to update
  * the status bar or something to indicate the the game is currently
- * waiting for server respose.
+ * waiting for server response.
  * Since the GUI may get disabled while waiting, it is good to let the
  * user know why all controls are unresponsive.
  */
@@ -609,7 +609,7 @@ static gboolean global_unhandled(StateMachine * sm, gint event)
 }
 
 /*----------------------------------------------------------------------
- * Server notifcations about player name changes and chat messages.
+ * Server notifications about player name changes and chat messages.
  * These can happen in any state (maybe this should be moved to
  * global_filter()?).
  */
@@ -637,7 +637,7 @@ static gboolean check_chat_or_name(StateMachine * sm)
 }
 
 /*----------------------------------------------------------------------
- * Server notifcations about other players name changes and chat
+ * Server notifications about other players name changes and chat
  * messages.  These can happen in almost any state in which the game
  * is running.
  */
@@ -1036,8 +1036,10 @@ static gboolean mode_load_game(StateMachine * sm, gint event)
 	if (event != SM_RECV)
 		return FALSE;
 	if (sm_recv(sm, "game")) {
-		if (game_params != NULL)
+		if (game_params != NULL) {
+			callbacks.set_map(NULL);
 			params_free(game_params);
+		}
 		game_params = params_new();
 		return TRUE;
 	}
@@ -1177,6 +1179,7 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 			return FALSE;
 		}
 
+		stock_dont_count_develop();
 		develop_bought_card_turn(devcard, devcardturnbought != 0);
 
 		devcardidx++;
