@@ -20,12 +20,12 @@
  */
 
 #include "config.h"
-#include <locale.h>
 #include <glib.h>
 
 #include "client.h"
 #include "callback.h"
 #include "network.h"
+#include "gettext.h"
 
 static GMainLoop *loop;
 
@@ -53,14 +53,8 @@ int main(int argc, char *argv[])
 	callbacks.quit = &quit;
 	loop = NULL;
 
-#if ENABLE_NLS
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
-
-	/* have gettext return strings in UTF-8 */
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
-#endif
+	/* Initialize translations */
+	gettext_init();
 
 	frontend_set_callbacks();
 
