@@ -25,8 +25,7 @@
 
 #include "avahi-browser.h"
 
-static void avahibrowser_class_init(AvahiBrowserClass * klass);
-static void avahibrowser_init(AvahiBrowser * ab);
+static void avahibrowser_init(GTypeInstance * instance, gpointer g_class);
 
 /* Register the class */
 GType avahibrowser_get_type(void)
@@ -38,30 +37,27 @@ GType avahibrowser_get_type(void)
 			sizeof(AvahiBrowserClass),
 			NULL,	/* base_init */
 			NULL,	/* base_finalize */
-			(GClassInitFunc) avahibrowser_class_init,
+			NULL,	/* class_init */
 			NULL,	/* class_finalize */
 			NULL,	/* class_data */
 			sizeof(AvahiBrowser),
 			0,
-			(GInstanceInitFunc) avahibrowser_init,
+			avahibrowser_init,
 			NULL
 		};
 		sg_type =
-		    g_type_register_static(GTK_TYPE_TABLE,
+		    g_type_register_static(GTK_TYPE_GRID,
 					   "AvahiBrowser", &sg_info, 0);
 	}
 	return sg_type;
 }
 
-static void avahibrowser_class_init(G_GNUC_UNUSED AvahiBrowserClass *
-				    klass)
-{
-}
-
 /* Build the composite widget */
-static void avahibrowser_init(AvahiBrowser * ab)
+static void avahibrowser_init(GTypeInstance * instance,
+			      G_GNUC_UNUSED gpointer g_class)
 {
 	GtkCellRenderer *cell;
+	AvahiBrowser *ab = AVAHIBROWSER(instance);
 
 	/* Create model */
 	ab->data =
@@ -81,9 +77,8 @@ static void avahibrowser_init(AvahiBrowser * ab)
 	gtk_widget_set_tooltip_text(ab->combo_box,
 				    _
 				    ("Select an automatically discovered game"));
-	gtk_table_resize(GTK_TABLE(ab), 1, 1);
-	gtk_table_attach_defaults(GTK_TABLE(ab), ab->combo_box, 0, 1, 0,
-				  1);
+	gtk_grid_attach(GTK_GRID(ab), ab->combo_box, 0, 1, 1, 1);
+	gtk_widget_set_hexpand(ab->combo_box, TRUE);
 }
 
 /* Create a new instance of the widget */
