@@ -129,7 +129,7 @@ GtkWidget *develop_build_page(void)
 			     /* Caption for list of bought development cards */
 			     _("<b>Development cards</b>"));
 	gtk_widget_show(label);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_container_add(GTK_CONTAINER(alignment), label);
 
 	/* Create model */
