@@ -102,8 +102,7 @@ static GtkWidget *discard_create_dlg(gint num)
 					"You must discard %d resources",
 					num), num);
 	discard.resource_widget =
-	    resource_table_new(text, RESOURCE_TABLE_LESS_IN_HAND, FALSE,
-			       TRUE);
+	    resource_table_new(text, RESOURCE_TABLE_LESS_IN_HAND, FALSE);
 	g_free(text);
 	resource_table_set_total(RESOURCETABLE(discard.resource_widget),
 				 /* Label */
@@ -234,7 +233,7 @@ GtkWidget *discard_build_page(void)
 			     /* Caption for list of player that must discard cards */
 			     _("<b>Waiting for players to discard</b>"));
 	gtk_widget_show(label);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_container_add(GTK_CONTAINER(alignment), label);
 
 	scroll_win = gtk_scrolled_window_new(NULL, NULL);
