@@ -71,7 +71,7 @@ gint hotkeys_handler(GtkWidget * w, GdkEvent * e, gpointer data);
 extern GtkWidget *app_window;	/* main application window */
 
 /* gui states */
-typedef void (*GuiState) (GuiEvent event);
+typedef void (*GuiState)(GuiEvent event);
 
 #define set_gui_state(A) do \
 		{ debug("New GUI_state: %s %p\n", #A, A); \
@@ -85,4 +85,17 @@ void gui_rules_register_callback(GCallback callback);
 
 void gui_set_show_no_setup_nodes(gboolean show);
 
+gboolean get_charity_enabled(void);
+void set_charity_enabled(gboolean new_charity_enabled);
+
+typedef enum {
+	ROLL_MANUALLY = 0,
+	ROLL_AUTOMATICALLY_EXCEPT_WITH_SOLDIER_CARD = 1,
+	ROLL_AUTOMATICALLY_EXCEPT_WITH_RESOURCE_CARD = 2,
+	ROLL_AUTOMATICALLY = 3
+} TAutomaticRoll;
+
+TAutomaticRoll get_automatic_roll(void);
+void set_automatic_roll(TAutomaticRoll automatic_roll);
+
 #endif
