@@ -24,7 +24,7 @@
 
 void histogram_dice_rolled(gint roll, gint playernum);
 
-GtkWidget *histogram_create_dlg(void);
+GtkWidget *histogram_create_dlg(GtkWindow * parent_window);
 void histogram_init(void);
 void histogram_reset(void);
 #endif
