@@ -38,8 +38,6 @@ struct _ResourceRow {
 	GtkWidget *amount_widget;
 
 	gint limit;
-	GtkWidget *less_widget;
-	GtkWidget *more_widget;
 };
 
 enum _ResourceTableDirection {
@@ -49,7 +47,7 @@ enum _ResourceTableDirection {
 typedef enum _ResourceTableDirection ResourceTableDirection;
 
 struct _ResourceTable {
-	GtkTable table;
+	GtkGrid grid;
 
 	struct _ResourceRow row[NO_RESOURCE];
 
@@ -65,15 +63,15 @@ struct _ResourceTable {
 };
 
 struct _ResourceTableClass {
-	GtkTableClass parent_class;
+	GtkGridClass parent_class;
 
-	void (*change) (ResourceTable * rt);
+	void (*change)(ResourceTable * rt);
 };
 
 GType resource_table_get_type(void);
 GtkWidget *resource_table_new(const gchar * title,
 			      ResourceTableDirection direction,
-			      gboolean with_bank, gboolean with_total);
+			      gboolean with_bank);
 
 void resource_table_limit_bank(ResourceTable * rt, gboolean limit);
 void resource_table_set_total(ResourceTable * rt, const gchar * text,
