@@ -44,7 +44,6 @@ static TradeRow we_receive_rows[NO_RESOURCE];
 
 static gint active_supply_request[NO_RESOURCE];
 static gint active_receive_request[NO_RESOURCE];
-static gboolean trade_since_selection_changed;
 
 /** This button can be hidden in games without interplayer trade */
 static GtkWidget *call_btn;
@@ -52,17 +51,21 @@ static GtkWidget *call_btn;
 static GtkWidget *we_receive_frame;
 /** The last quote that is called */
 static GtkWidget *active_quote_label;
+/** Prevent charity, can be hidden in games without interplayer trade */
+static GtkWidget *charity_enabled_checkbutton;
 
 /** @return TRUE is we can accept this domestic quote */
 static gboolean is_good_quote(const QuoteInfo * quote)
 {
 	gint idx;
 	gboolean interested;
+	gboolean have_we_receive;
 
 	g_assert(quote != NULL);
 	g_assert(quote->is_domestic);
 
 	interested = FALSE;
+	have_we_receive = FALSE;
 	for (idx = 0; idx < NO_RESOURCE; idx++) {
 		gint we_supply = quote->var.d.receive[idx];
 		gint we_receive = quote->var.d.supply[idx];
@@ -76,8 +79,10 @@ static gboolean is_good_quote(const QuoteInfo * quote)
 		if (we_receive > 0 && we_receive_rows[idx].enabled) {
 			interested = TRUE;
 		}
+		have_we_receive = have_we_receive || (we_receive > 0);
 	}
-	return interested;
+	/* We also also interested if we allow giving away resources */
+	return interested || (!have_we_receive && get_charity_enabled());
 }
 
 /** @return TRUE if at least one resource is asked/offered */
@@ -87,6 +92,7 @@ gboolean can_call_for_quotes(void)
 	gboolean have_we_receive;
 	gboolean have_we_supply;
 	gboolean different_call;
+	gboolean is_charity;
 
 	different_call = FALSE;
 	have_we_receive = have_we_supply = FALSE;
@@ -102,11 +108,20 @@ gboolean can_call_for_quotes(void)
 		if (we_supply_rows[idx].enabled)
 			have_we_supply = TRUE;
 	}
-	/* don't require both supply and receive, for resources may be
-	 * given away for free */
+	is_charity = !have_we_receive || !have_we_supply;
+
+	/* Trade is allowed when all applies:
+	 * 1) at least one resource type is requested
+	 * 2) domestic trade is allowed
+	 * 3) the request differs from the active request
+	 * 4) either
+	 *    a. the trade is not a donation
+	 *    b. the trade is a donation, and charity is allowed
+	 */
 	return (have_we_receive || have_we_supply)
 	    && can_trade_domestic()
-	    && (different_call || trade_since_selection_changed);
+	    && different_call
+	    && (!is_charity || (is_charity && get_charity_enabled()));
 }
 
 /** @return the current quote */
@@ -234,7 +249,6 @@ void trade_new_trade(void)
 		active_supply_request[idx] = we_supply_rows[idx].enabled;
 		active_receive_request[idx] = we_receive_rows[idx].enabled;
 	}
-	trade_since_selection_changed = FALSE;
 
 	resource_format_type(we_supply_desc, active_supply_request);
 	resource_format_type(we_receive_desc, active_receive_request);
@@ -265,7 +279,7 @@ static void toggled_cb(GtkWidget * widget, TradeRow * row)
 }
 
 /** Add a row with widgets for a resource */
-static void add_trade_row(GtkWidget * table, TradeRow * row,
+static void add_trade_row(GtkWidget * grid, TradeRow * row,
 			  Resource resource)
 {
 	gint col;
@@ -277,9 +291,7 @@ static void add_trade_row(GtkWidget * table, TradeRow * row,
 	g_signal_connect(G_OBJECT(row->chk), "toggled",
 			 G_CALLBACK(toggled_cb), row);
 	gtk_widget_show(row->chk);
-	gtk_table_attach(GTK_TABLE(table), row->chk,
-			 col, col + 1, resource, resource + 1,
-			 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(grid), row->chk, col, resource, 1, 1);
 	col++;
 
 	row->curr = gtk_entry_new();
@@ -287,9 +299,7 @@ static void add_trade_row(GtkWidget * table, TradeRow * row,
 	gtk_entry_set_alignment(GTK_ENTRY(row->curr), 1.0);
 	gtk_widget_set_sensitive(row->curr, FALSE);
 	gtk_widget_show(row->curr);
-	gtk_table_attach(GTK_TABLE(table), row->curr,
-			 col, col + 1, resource, resource + 1,
-			 GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(grid), row->curr, col, resource, 1, 1);
 }
 
 /** Set the sensitivity of the row, and update the assets when applicable */
@@ -347,7 +357,7 @@ void trade_add_quote(gint player_num,
 				     /* Notification */
 				     _("Quote received from %s."),
 				     player_name(player_num, FALSE));
-	notification_send(msg, PIONEERS_PIXMAP_TRADE);
+	notification_send(msg, ICON_TRADE);
 	g_free(msg);
 }
 
@@ -397,11 +407,16 @@ void trade_begin(void)
 		gtk_widget_hide(we_receive_frame);
 		gtk_widget_hide(call_btn);
 		gtk_widget_hide(active_quote_label);
+		gtk_widget_hide(charity_enabled_checkbutton);
 	} else {
 		gtk_widget_show(we_receive_frame);
 		gtk_widget_show(call_btn);
 		gtk_widget_show(active_quote_label);
 		gtk_label_set_text(GTK_LABEL(active_quote_label), "");
+		gtk_widget_show(charity_enabled_checkbutton);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+					     (charity_enabled_checkbutton),
+					     get_charity_enabled());
 	}
 	quote_view_clear_selected_quote(QUOTEVIEW(quoteview));
 	update_rows();		/* Always update */
@@ -422,6 +437,15 @@ static void quote_selected_cb(G_GNUC_UNUSED QuoteView * quoteview,
 	frontend_gui_update();
 }
 
+static void charity_enabled_cb(GtkToggleButton * widget,
+			       G_GNUC_UNUSED gpointer user_data)
+{
+	gboolean charity_enabled = gtk_toggle_button_get_active(widget);
+	set_charity_enabled(charity_enabled);
+	trade_update();
+	frontend_gui_update();
+}
+
 /** Build a trade resources composite widget.
  *  @param title The title for the composite widget.
  *  @param trade_rows Pointer to TradeRow to store each row's data.
@@ -433,13 +457,13 @@ static GtkWidget *build_trade_resources_frame(const gchar * title,
 	/* vbox */
 	/*       label */
 	/*       alignment */
-	/*               table */
+	/*               grid */
 	/*                       trade rows */
 
 	GtkWidget *vbox;
 	GtkWidget *label;
 	GtkWidget *alignment;
-	GtkWidget *table;
+	GtkWidget *grid;
 
 	gchar *title_with_markup;
 	gint idx;
@@ -452,7 +476,7 @@ static GtkWidget *build_trade_resources_frame(const gchar * title,
 	gtk_label_set_markup(GTK_LABEL(label), title_with_markup);
 	g_free(title_with_markup);
 	gtk_widget_show(label);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
 	alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
@@ -461,16 +485,16 @@ static GtkWidget *build_trade_resources_frame(const gchar * title,
 	gtk_widget_show(alignment);
 	gtk_box_pack_start(GTK_BOX(vbox), alignment, FALSE, FALSE, 0);
 
-	table = gtk_table_new(NO_RESOURCE, 2, FALSE);
-	gtk_widget_show(table);
-	gtk_container_add(GTK_CONTAINER(alignment), table);
-	gtk_container_set_border_width(GTK_CONTAINER(table), 0);
-	gtk_table_set_row_spacings(GTK_TABLE(table), 3);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 3);
+	grid = gtk_grid_new();
+	gtk_widget_show(grid);
+	gtk_container_add(GTK_CONTAINER(alignment), grid);
+	gtk_container_set_border_width(GTK_CONTAINER(grid), 0);
+	gtk_grid_set_row_spacing(GTK_GRID(grid), 3);
+	gtk_grid_set_column_spacing(GTK_GRID(grid), 3);
 
 	/* trade rows, one for each resource */
 	for (idx = 0; idx < NO_RESOURCE; ++idx)
-		add_trade_row(table, trade_rows + idx, idx);
+		add_trade_row(grid, trade_rows + idx, idx);
 
 	return vbox;
 }
@@ -487,6 +511,7 @@ GtkWidget *trade_build_page(void)
 	/*                       trade_resources_frame */
 	/*                       hbox - bbox */
 	/*                               call_btn */
+	/*                       charity */
 	/*               vbox */
 	/*                       active_quote_label */
 	/*                       quoteview */
@@ -541,13 +566,29 @@ GtkWidget *trade_build_page(void)
 	gtk_widget_show(call_btn);
 	gtk_container_add(GTK_CONTAINER(bbox), call_btn);
 
+	/* Label text, trade: charity */
+	charity_enabled_checkbutton =
+	    gtk_check_button_new_with_label(_("Enable Charity"));
+	gtk_widget_show(charity_enabled_checkbutton);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (charity_enabled_checkbutton),
+				     get_charity_enabled());
+	g_signal_connect(G_OBJECT(charity_enabled_checkbutton), "toggled",
+			 G_CALLBACK(charity_enabled_cb), NULL);
+	gtk_box_pack_start(GTK_BOX(vbox), charity_enabled_checkbutton,
+			   FALSE, TRUE, 0);
+	gtk_widget_set_tooltip_text(charity_enabled_checkbutton,
+				    /* Tooltip for the option to enable charity */
+				    _(""
+				      "When checked, a resource can be given away without receiving anything back"));
+
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 	gtk_widget_show(vbox);
 	gtk_box_pack_start(GTK_BOX(panel_mainbox), vbox, TRUE, TRUE, 0);
 
 	active_quote_label = gtk_label_new("");
 	gtk_widget_show(active_quote_label);
-	gtk_misc_set_alignment(GTK_MISC(active_quote_label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(active_quote_label), 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox), active_quote_label,
 			   FALSE, FALSE, 0);
 
@@ -599,5 +640,4 @@ static void trade_update(void)
 		set_row_sensitive(we_supply_rows + idx);
 	}
 	quote_view_check_validity_of_trades(QUOTEVIEW(quoteview));
-	trade_since_selection_changed = TRUE;
 }
