@@ -134,10 +134,10 @@ typedef enum {
 } PlayerType;
 #define NUM_PLAYER_TYPES (PLAYER_UNKNOWN + 1)
 
-typedef void (*WriteLineFunc) (gpointer user_data, const gchar *);
+typedef void (*WriteLineFunc)(gpointer user_data, const gchar *);
 
 /** Default style for a player. */
-const gchar *default_player_style;
+extern const gchar *default_player_style;
 
 GameParams *params_new(void);
 GameParams *params_copy(const GameParams * params);
