@@ -27,7 +27,6 @@
 #include "common_gtk.h"
 #include "cards.h"
 
-static GtkCssProvider *small_button_style_provider;
 static GtkWidget *message_txt;
 static GtkWidget *message_container;
 static gboolean msg_colors = TRUE;
@@ -332,23 +331,6 @@ void check_victory_points(GameParams * params, GtkWindow * main_window)
 	g_free(point_specification);
 }
 
-void prepare_gtk_for_close_button_on_tab(void)
-{
-	/* The code for adding the button is based on the code on
-	 * http://www.micahcarrick.com/gtk-notebook-tabs-with-close-button.html
-	 * by Micah Carrick
-	 */
-	const gchar *data = ".button {\n"
-	    "-GtkButton-default-border : 0px;\n"
-	    "-GtkButton-default-outside-border : 0px;\n"
-	    "-GtkButton-inner-border: 0px;\n"
-	    "-GtkWidget-focus-line-width : 0px;\n"
-	    "-GtkWidget-focus-padding : 0px;\n" "padding: 0px;\n" "}";
-	small_button_style_provider = gtk_css_provider_new();
-	gtk_css_provider_load_from_data(small_button_style_provider, data,
-					-1, NULL);
-}
-
 GtkWidget *create_label_with_close_button(const gchar * label_text,
 					  const gchar * tooltip_text,
 					  GtkWidget ** button)
@@ -371,13 +353,6 @@ GtkWidget *create_label_with_close_button(const gchar * label_text,
 	gtk_widget_set_tooltip_text(*button, tooltip_text);
 	gtk_box_pack_start(GTK_BOX(hbox), *button, FALSE, FALSE, 0);
 
-	/* Apply the style, to make the button smaller */
-	gtk_style_context_add_provider(gtk_widget_get_style_context
-				       (*button),
-				       GTK_STYLE_PROVIDER
-				       (small_button_style_provider),
-				       GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
 	gtk_widget_show_all(hbox);
 	return hbox;
 }
@@ -405,7 +380,7 @@ void build_frame(GtkWidget * parent, const gchar * title,
 	title_with_markup = g_strdup_printf("<b>%s</b>", title);
 	gtk_label_set_markup(GTK_LABEL(label), title_with_markup);
 	g_free(title_with_markup);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
