@@ -22,8 +22,9 @@ enum {
 	LAST_SIGNAL
 };
 
-static void game_settings_class_init(GameSettingsClass * klass);
-static void game_settings_init(GameSettings * sg);
+static void game_settings_class_init(gpointer g_class,
+				     gpointer class_data);
+static void game_settings_init(GTypeInstance * instance, gpointer g_class);
 static void game_settings_change_players(GtkSpinButton * widget,
 					 GameSettings * gs);
 static void game_settings_change_victory_points(GtkSpinButton * widget,
@@ -44,16 +45,16 @@ GType game_settings_get_type(void)
 			sizeof(GameSettingsClass),
 			NULL,	/* base_init */
 			NULL,	/* base_finalize */
-			(GClassInitFunc) game_settings_class_init,
+			game_settings_class_init,
 			NULL,	/* class_finalize */
 			NULL,	/* class_data */
 			sizeof(GameSettings),
 			0,
-			(GInstanceInitFunc) game_settings_init,
+			game_settings_init,
 			NULL
 		};
 		gs_type =
-		    g_type_register_static(GTK_TYPE_TABLE, "GameSettings",
+		    g_type_register_static(GTK_TYPE_GRID, "GameSettings",
 					   &gs_info, 0);
 	}
 	return gs_type;
@@ -64,11 +65,12 @@ GType game_settings_get_type(void)
  * 'change'         when any change to one of the controls occurs.
  * 'change-players' when the amount of player has changed.
  */
-static void game_settings_class_init(GameSettingsClass * klass)
+static void game_settings_class_init(gpointer g_class,
+				     G_GNUC_UNUSED gpointer class_data)
 {
 	game_settings_signals[CHANGE] = g_signal_new("change",
 						     G_TYPE_FROM_CLASS
-						     (klass),
+						     (g_class),
 						     G_SIGNAL_RUN_FIRST |
 						     G_SIGNAL_ACTION,
 						     G_STRUCT_OFFSET
@@ -77,13 +79,13 @@ static void game_settings_class_init(GameSettingsClass * klass)
 						     g_cclosure_marshal_VOID__VOID,
 						     G_TYPE_NONE, 0);
 	game_settings_signals[CHANGE_PLAYERS] =
-	    g_signal_new("change-players", G_TYPE_FROM_CLASS(klass),
+	    g_signal_new("change-players", G_TYPE_FROM_CLASS(g_class),
 			 G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
 			 G_STRUCT_OFFSET(GameSettingsClass,
 					 change_players), NULL, NULL,
 			 g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 	game_settings_signals[CHECK] =
-	    g_signal_new("check", G_TYPE_FROM_CLASS(klass),
+	    g_signal_new("check", G_TYPE_FROM_CLASS(g_class),
 			 G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
 			 G_STRUCT_OFFSET(GameSettingsClass, check), NULL,
 			 NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
@@ -91,32 +93,33 @@ static void game_settings_class_init(GameSettingsClass * klass)
 }
 
 /* Build the composite widget */
-static void game_settings_init(GameSettings * gs)
+static void game_settings_init(GTypeInstance * instance,
+			       G_GNUC_UNUSED gpointer g_class)
 {
 	GtkWidget *label;
 	GtkWidget *hbox;
 	GtkAdjustment *adj;
+	GameSettings *gs = GAMESETTINGS(instance);
 
-	gtk_table_resize(GTK_TABLE(gs), 4, 2);
-	gtk_table_set_row_spacings(GTK_TABLE(gs), 3);
-	gtk_table_set_col_spacings(GTK_TABLE(gs), 5);
+	gtk_grid_set_row_spacing(GTK_GRID(gs), 3);
+	gtk_grid_set_column_spacing(GTK_GRID(gs), 5);
+	gtk_widget_set_hexpand(GTK_WIDGET(gs), FALSE);
 
 	/* Label text for customising a game */
 	label = gtk_label_new(_("Number of players"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(gs), label, 0, 1, 1, 2,
-			 GTK_FILL, GTK_FILL, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5f);
+	gtk_grid_attach(GTK_GRID(gs), label, 0, 1, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	adj =
 	    GTK_ADJUSTMENT(gtk_adjustment_new(0, 2, MAX_PLAYERS, 1, 4, 0));
 	gs->players_spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
 	gtk_entry_set_alignment(GTK_ENTRY(gs->players_spin), 1.0);
 	gtk_widget_show(gs->players_spin);
+	gtk_widget_set_hexpand(gs->players_spin, TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(gs->players_spin),
 				    TRUE);
-	gtk_table_attach(GTK_TABLE(gs), gs->players_spin, 1, 2, 1, 2,
-			 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(gs), gs->players_spin, 1, 1, 1, 1);
 	g_signal_connect(G_OBJECT(gs->players_spin), "value-changed",
 			 G_CALLBACK(game_settings_change_players), gs);
 	gtk_widget_set_tooltip_text(gs->players_spin,
@@ -126,9 +129,8 @@ static void game_settings_init(GameSettings * gs)
 	/* Label for customising a game */
 	label = gtk_label_new(_("Victory point target"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(gs), label, 0, 1, 2, 3,
-			 GTK_FILL, GTK_FILL, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5f);
+	gtk_grid_attach(GTK_GRID(gs), label, 0, 2, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3);
 
@@ -160,8 +162,7 @@ static void game_settings_init(GameSettings * gs)
 				    /* Tooltip for the check button */
 				    _("Is it possible to win this game?"));
 
-	gtk_table_attach(GTK_TABLE(gs), hbox, 1, 2, 2, 3,
-			 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(gs), hbox, 1, 2, 1, 1);
 	gtk_widget_show(hbox);
 
 	gs->players = 4;
@@ -251,7 +252,7 @@ static void game_settings_update(GameSettings * gs)
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(gs->victory_spin),
 				  gs->victory_points);
 
-	/* Reenable the signals */
+	/* Re-enable the signals */
 	g_signal_handlers_unblock_matched(G_OBJECT(gs->players_spin),
 					  G_SIGNAL_MATCH_DATA,
 					  0, 0, NULL, NULL, gs);
