@@ -153,11 +153,9 @@ static gboolean draw_map_cb(GtkWidget * area, cairo_t * cr,
 }
 
 static gint configure_map_cb(GtkWidget * area,
-			     G_GNUC_UNUSED GdkEventConfigure * event,
-			     gpointer user_data)
+			     GdkEventConfigure * event, gpointer user_data)
 {
 	GuiMap *gmap = user_data;
-	GtkAllocation allocation;
 
 	if (gtk_widget_get_window(area) == NULL || gmap->map == NULL)
 		return FALSE;
@@ -166,8 +164,7 @@ static gint configure_map_cb(GtkWidget * area,
 		cairo_surface_destroy(gmap->surface);
 		gmap->surface = NULL;
 	}
-	gtk_widget_get_allocation(area, &allocation);
-	guimap_scale_to_size(gmap, allocation.width, allocation.height);
+	guimap_scale_to_size(gmap, event->width, event->height);
 
 	gtk_widget_queue_draw(area);
 	return FALSE;
@@ -212,38 +209,37 @@ static gboolean zoom_map_cb(GtkWidget * area, GdkEventScroll * event,
 			    gpointer user_data)
 {
 	GuiMap *gmap = user_data;
-	GtkAllocation allocation;
 	gint radius;
+	gdouble old_width;
+	gdouble old_height;
 
 	if (gtk_widget_get_window(area) == NULL || gmap->map == NULL)
 		return FALSE;
 
 	radius = gmap->hex_radius;
+	old_width = gmap->width;
+	old_height = gmap->height;
+
 	gmap->is_custom_view = TRUE;
 
 	if (event->direction == GDK_SCROLL_UP) {
 		radius += ZOOM_AMOUNT;
-
-		gmap->x_margin -= (event->x - gmap->x_margin) *
-		    ZOOM_AMOUNT / radius;
-		gmap->y_margin -= (event->y - gmap->y_margin) *
-		    ZOOM_AMOUNT / radius;
-
 	} else if (event->direction == GDK_SCROLL_DOWN) {
-		gint old_radius = radius;
 		radius -= ZOOM_AMOUNT;
 		if (radius < MIN_HEX_RADIUS)
 			radius = MIN_HEX_RADIUS;
-
-		gmap->x_margin += (event->x - gmap->x_margin) *
-		    (old_radius - radius) / radius;
-		gmap->y_margin += (event->y - gmap->y_margin) *
-		    (old_radius - radius) / radius;
-
 	}
-	gmap->hex_radius = radius;
-	gtk_widget_get_allocation(gmap->area, &allocation);
-	guimap_scale_to_size(gmap, allocation.width, allocation.height);
+
+	guimap_scale_with_radius(gmap, radius);
+
+	gmap->x_margin =
+	    event->x - (event->x -
+			gmap->x_margin) / old_width *
+	    (gdouble) gmap->width;
+	gmap->y_margin =
+	    event->y - (event->y -
+			gmap->y_margin) / old_height *
+	    (gdouble) gmap->height;
 
 	guimap_display(gmap);
 	gtk_widget_queue_draw(gmap->area);
@@ -263,7 +259,8 @@ GtkWidget *guimap_build_drawingarea(GuiMap * gmap, gint width, gint height)
 
 	gtk_widget_set_events(gmap->area, GDK_EXPOSURE_MASK
 			      | GDK_POINTER_MOTION_MASK
-			      | GDK_POINTER_MOTION_HINT_MASK);
+			      | GDK_POINTER_MOTION_HINT_MASK
+			      | GDK_SCROLL_MASK);
 
 	gtk_widget_set_size_request(gmap->area, width, height);
 	g_signal_connect(G_OBJECT(gmap->area), "draw",
@@ -282,8 +279,8 @@ GtkWidget *guimap_build_drawingarea(GuiMap * gmap, gint width, gint height)
 }
 
 static GdkPoint settlement_points[] = {
-	{20, 20}, {20, -8}, {0, -28}, {-20, -8},
-	{-20, 20}, {20, 20}
+	{ 20, 20 }, { 20, -8 }, { 0, -28 }, { -20, -8 },
+	{ -20, 20 }, { 20, 20 }
 };
 
 static Polygon settlement_poly = {
@@ -292,8 +289,8 @@ static Polygon settlement_poly = {
 };
 
 static GdkPoint city_points[] = {
-	{40, 20}, {40, -16}, {2, -16}, {2, -28},
-	{-19, -48}, {-40, -28}, {-40, 20}, {40, 20}
+	{ 40, 20 }, { 40, -16 }, { 2, -16 }, { 2, -28 },
+	{ -19, -48 }, { -40, -28 }, { -40, 20 }, { 40, 20 }
 };
 
 static Polygon city_poly = {
@@ -302,7 +299,7 @@ static Polygon city_poly = {
 };
 
 static GdkPoint city_wall_points[] = {
-	{50, 36}, {50, -64}, {-50, -64}, {-50, 36}
+	{ 50, 36 }, { 50, -64 }, { -50, -64 }, { -50, 36 }
 };
 
 static Polygon city_wall_poly = {
@@ -311,8 +308,8 @@ static Polygon city_wall_poly = {
 };
 
 static GdkPoint nosetup_points[] = {
-	{0, 30}, {26, 15}, {26, -15}, {0, -30},
-	{-26, -15}, {-26, 15}, {0, 30}
+	{ 0, 30 }, { 26, 15 }, { 26, -15 }, { 0, -30 },
+	{ -26, -15 }, { -26, 15 }, { 0, 30 }
 };
 
 static Polygon nosetup_poly = {
@@ -327,10 +324,10 @@ static Polygon nosetup_poly = {
 #define NODE_MAX_Y 36
 
 static GdkPoint largest_node_points[] = {
-	{NODE_MIN_X, NODE_MIN_Y},
-	{NODE_MIN_X, NODE_MAX_Y},
-	{NODE_MAX_X, NODE_MAX_Y},
-	{NODE_MAX_X, NODE_MIN_Y}
+	{ NODE_MIN_X, NODE_MIN_Y },
+	{ NODE_MIN_X, NODE_MAX_Y },
+	{ NODE_MAX_X, NODE_MAX_Y },
+	{ NODE_MAX_X, NODE_MIN_Y }
 };
 
 static Polygon largest_node_poly = {
@@ -339,8 +336,8 @@ static Polygon largest_node_poly = {
 };
 
 static GdkPoint road_points[] = {
-	{10, 40}, {10, -40}, {-10, -40}, {-10, 40},
-	{10, 40}
+	{ 10, 40 }, { 10, -40 }, { -10, -40 }, { -10, 40 },
+	{ 10, 40 }
 };
 
 static Polygon road_poly = {
@@ -349,10 +346,10 @@ static Polygon road_poly = {
 };
 
 static GdkPoint ship_points[] = {
-	{10, 32}, {10, 8}, {24, 18}, {42, 8},
-	{48, 0}, {50, -12}, {10, -12}, {10, -32},
-	{2, -32}, {-6, -26}, {-10, -16}, {-10, 16},
-	{-6, 26}, {2, 32}, {10, 32}
+	{ 10, 32 }, { 10, 8 }, { 24, 18 }, { 42, 8 },
+	{ 48, 0 }, { 50, -12 }, { 10, -12 }, { 10, -32 },
+	{ 2, -32 }, { -6, -26 }, { -10, -16 }, { -10, 16 },
+	{ -6, 26 }, { 2, 32 }, { 10, 32 }
 };
 
 static Polygon ship_poly = {
@@ -361,9 +358,9 @@ static Polygon ship_poly = {
 };
 
 static GdkPoint bridge_points[] = {
-	{13, 40}, {-14, 40}, {-14, 30}, {-1, 15},
-	{-1, -15}, {-14, -30}, {-14, -40}, {13, -40},
-	{13, 40}
+	{ 13, 40 }, { -14, 40 }, { -14, 30 }, { -1, 15 },
+	{ -1, -15 }, { -14, -30 }, { -14, -40 }, { 13, -40 },
+	{ 13, 40 }
 };
 
 static Polygon bridge_poly = {
@@ -378,10 +375,10 @@ static Polygon bridge_poly = {
 #define EDGE_MAX_Y 40
 
 static GdkPoint largest_edge_points[] = {
-	{EDGE_MIN_X, EDGE_MIN_Y},
-	{EDGE_MIN_X, EDGE_MAX_Y},
-	{EDGE_MAX_X, EDGE_MAX_Y},
-	{EDGE_MAX_X, EDGE_MIN_Y}
+	{ EDGE_MIN_X, EDGE_MIN_Y },
+	{ EDGE_MIN_X, EDGE_MAX_Y },
+	{ EDGE_MAX_X, EDGE_MAX_Y },
+	{ EDGE_MAX_X, EDGE_MIN_Y }
 };
 
 static Polygon largest_edge_poly = {
@@ -390,11 +387,11 @@ static Polygon largest_edge_poly = {
 };
 
 static GdkPoint robber_points[] = {
-	{30, 60}, {30, 4}, {28, -6}, {22, -15},
-	{12, -20}, {22, -32}, {22, -48}, {10, -60},
-	{-10, -60}, {-22, -48}, {-22, -32}, {-12, -20},
-	{-22, -15}, {-28, -6}, {-30, 4}, {-30, 60},
-	{30, 60}
+	{ 30, 60 }, { 30, 4 }, { 28, -6 }, { 22, -15 },
+	{ 12, -20 }, { 22, -32 }, { 22, -48 }, { 10, -60 },
+	{ -10, -60 }, { -22, -48 }, { -22, -32 }, { -12, -20 },
+	{ -22, -15 }, { -28, -6 }, { -30, 4 }, { -30, 60 },
+	{ 30, 60 }
 };
 
 static Polygon robber_poly = {
@@ -403,10 +400,10 @@ static Polygon robber_poly = {
 };
 
 static GdkPoint pirate_points[] = {
-	{42, 15}, {18, 15}, {28, 1}, {18, -17},
-	{10, -23}, {-2, -25}, {-2, 15}, {-22, 15},
-	{-22, 23}, {-16, 31}, {-6, 35}, {26, 35},
-	{36, 31}, {42, 23}, {42, 15}
+	{ 42, 15 }, { 18, 15 }, { 28, 1 }, { 18, -17 },
+	{ 10, -23 }, { -2, -25 }, { -2, 15 }, { -22, 15 },
+	{ -22, 23 }, { -16, 31 }, { -6, 35 }, { 26, 35 },
+	{ 36, 31 }, { 42, 23 }, { 42, 15 }
 };
 
 static Polygon pirate_poly = {
@@ -710,9 +707,9 @@ void draw_port_indicator(PangoLayout * layout, cairo_t * cr,
 			typeind = TRUE;
 			drawit = TRUE;
 		} else if (!theme->colors[TC_PORT_BG].transparent) {
-			gdk_cairo_set_source_color(cr,
-						   &theme->colors
-						   [TC_PORT_BG].color);
+			gdk_cairo_set_source_rgba(cr,
+						  &theme->colors
+						  [TC_PORT_BG].color);
 			typeind = FALSE;
 			drawit = TRUE;
 		} else {
@@ -727,9 +724,9 @@ void draw_port_indicator(PangoLayout * layout, cairo_t * cr,
 
 		/* Outline port indicator */
 		if (!theme->colors[TC_PORT_BD].transparent) {
-			gdk_cairo_set_source_color(cr,
-						   &theme->colors
-						   [TC_PORT_BD].color);
+			gdk_cairo_set_source_rgba(cr,
+						  &theme->colors
+						  [TC_PORT_BD].color);
 			cairo_arc(cr, x_offset, y_offset,
 				  chit_radius, 0.0, 2 * M_PI);
 			cairo_stroke(cr);
@@ -774,9 +771,9 @@ void draw_port_indicator(PangoLayout * layout, cairo_t * cr,
 			pango_layout_set_markup(layout, str, -1);
 			pango_layout_get_pixel_size(layout, &width,
 						    &height);
-			gdk_cairo_set_source_color(cr,
-						   &theme->colors
-						   [TC_PORT_FG].color);
+			gdk_cairo_set_source_rgba(cr,
+						  &theme->colors
+						  [TC_PORT_FG].color);
 			cairo_move_to(cr, x_offset - width / 2,
 				      y_offset - height / 2);
 			pango_cairo_show_layout(cr, layout);
@@ -808,14 +805,14 @@ void draw_dice_roll(PangoLayout * layout, cairo_t * cr,
 	col = highlight ? TC_CHIP_H_BG : TC_CHIP_BG;
 	tcol = col_or_ovr(terrain, col);
 	if (!tcol->transparent) {
-		gdk_cairo_set_source_color(cr, &(tcol->color));
+		gdk_cairo_set_source_rgba(cr, &(tcol->color));
 		cairo_move_to(cr, x_offset + radius, y_offset);
 		cairo_arc(cr, x_offset, y_offset, radius, 0.0, 2 * M_PI);
 		cairo_fill(cr);
 	}
 	tcol = col_or_ovr(terrain, TC_CHIP_BD);
 	if (!tcol->transparent) {
-		gdk_cairo_set_source_color(cr, &(tcol->color));
+		gdk_cairo_set_source_rgba(cr, &(tcol->color));
 		cairo_move_to(cr, x_offset + radius, y_offset);
 		cairo_arc(cr, x_offset, y_offset, radius, 0.0, 2 * M_PI);
 		cairo_stroke(cr);
@@ -826,7 +823,7 @@ void draw_dice_roll(PangoLayout * layout, cairo_t * cr,
 		sprintf(num, "<b>%d</b>", n);
 		pango_layout_set_markup(layout, num, -1);
 		pango_layout_get_pixel_size(layout, &width, &height);
-		gdk_cairo_set_source_color(cr, &(tcol->color));
+		gdk_cairo_set_source_rgba(cr, &(tcol->color));
 		cairo_move_to(cr, x_offset - width / 2,
 			      y_offset - height / 2);
 		pango_cairo_show_layout(cr, layout);
@@ -875,9 +872,8 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 
 	/* Draw border around hex */
 	if (!theme->colors[TC_HEX_BD].transparent) {
-		gdk_cairo_set_source_color(gmap->cr,
-					   &theme->
-					   colors[TC_HEX_BD].color);
+		gdk_cairo_set_source_rgba(gmap->cr,
+					  &theme->colors[TC_HEX_BD].color);
 		poly_draw(gmap->cr, FALSE, &poly);
 	}
 
@@ -896,7 +892,7 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 		const double dashes[] = { 4.0 };
 
 		/* Draw lines from port to shore */
-		gdk_cairo_set_source_color(gmap->cr, &white);
+		gdk_cairo_set_source_rgba(gmap->cr, &white);
 		cairo_set_dash(gmap->cr, dashes, G_N_ELEMENTS(dashes),
 			       0.0);
 		cairo_move_to(gmap->cr, x_offset, y_offset);
@@ -935,15 +931,15 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 			g_assert_not_reached();
 			break;
 		}
-		gdk_cairo_set_source_color(gmap->cr,
-					   colors_get_player(edge->owner));
+		gdk_cairo_set_source_rgba(gmap->cr,
+					  colors_get_player(edge->owner));
 		poly_draw_with_border(gmap->cr, &black, &poly);
 	}
 
 	/* Draw all buildings */
 	for (idx = 0; idx < G_N_ELEMENTS(hex->nodes); idx++) {
 		const Node *node = hex->nodes[idx];
-		const GdkColor *color;
+		const GdkRGBA *color;
 
 		if (node->owner < 0 && !gmap->show_nosetup_nodes)
 			continue;
@@ -962,8 +958,7 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 				poly.num_points = G_N_ELEMENTS(points);
 				guimap_city_wall_polygon(gmap, node,
 							 &poly);
-				gdk_cairo_set_source_color(gmap->cr,
-							   color);
+				gdk_cairo_set_source_rgba(gmap->cr, color);
 				poly_draw_with_border(gmap->cr, &black,
 						      &poly);
 			}
@@ -976,7 +971,7 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 				guimap_settlement_polygon(gmap, node,
 							  &poly);
 		}
-		gdk_cairo_set_source_color(gmap->cr, color);
+		gdk_cairo_set_source_rgba(gmap->cr, color);
 		poly_draw_with_border(gmap->cr, &black, &poly);
 	}
 
@@ -986,15 +981,15 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 		guimap_robber_polygon(gmap, hex, &poly);
 		cairo_set_line_width(gmap->cr, 1.0);
 		if (!theme->colors[TC_ROBBER_FG].transparent) {
-			gdk_cairo_set_source_color(gmap->cr,
-						   &theme->colors
-						   [TC_ROBBER_FG].color);
+			gdk_cairo_set_source_rgba(gmap->cr,
+						  &theme->colors
+						  [TC_ROBBER_FG].color);
 			poly_draw(gmap->cr, TRUE, &poly);
 		}
 		if (!theme->colors[TC_ROBBER_BD].transparent) {
-			gdk_cairo_set_source_color(gmap->cr,
-						   &theme->colors
-						   [TC_ROBBER_BD].color);
+			gdk_cairo_set_source_rgba(gmap->cr,
+						  &theme->colors
+						  [TC_ROBBER_BD].color);
 			poly_draw(gmap->cr, FALSE, &poly);
 		}
 	}
@@ -1005,15 +1000,15 @@ static gboolean display_hex(const Hex * hex, gpointer closure)
 		guimap_pirate_polygon(gmap, hex, &poly);
 		cairo_set_line_width(gmap->cr, 1.0);
 		if (!theme->colors[TC_ROBBER_FG].transparent) {
-			gdk_cairo_set_source_color(gmap->cr,
-						   &theme->colors
-						   [TC_ROBBER_FG].color);
+			gdk_cairo_set_source_rgba(gmap->cr,
+						  &theme->colors
+						  [TC_ROBBER_FG].color);
 			poly_draw(gmap->cr, TRUE, &poly);
 		}
 		if (!theme->colors[TC_ROBBER_BD].transparent) {
-			gdk_cairo_set_source_color(gmap->cr,
-						   &theme->colors
-						   [TC_ROBBER_BD].color);
+			gdk_cairo_set_source_rgba(gmap->cr,
+						  &theme->colors
+						  [TC_ROBBER_BD].color);
 			poly_draw(gmap->cr, FALSE, &poly);
 		}
 	}
@@ -1030,8 +1025,6 @@ void guimap_scale_with_radius(GuiMap * gmap, gint radius)
 	gmap->x_point = radius * cos(M_PI / 6.0);
 	gmap->y_point = radius * sin(M_PI / 6.0);
 
-	gmap->x_margin = gmap->y_margin = 0;
-
 	if (gmap->map == NULL)
 		return;
 
@@ -1064,13 +1057,7 @@ void guimap_scale_to_size(GuiMap * gmap, gint width, gint height)
 	gint height_radius;
 
 	if (gmap->is_custom_view) {
-		gint x_margin = gmap->x_margin;
-		gint y_margin = gmap->y_margin;
 		guimap_scale_with_radius(gmap, gmap->hex_radius);
-		gmap->x_margin = x_margin;
-		gmap->y_margin = y_margin;
-		gmap->width = width;
-		gmap->height = height;
 		return;
 	}
 
@@ -1087,11 +1074,8 @@ void guimap_scale_to_size(GuiMap * gmap, gint width, gint height)
 	else
 		guimap_scale_with_radius(gmap, height_radius);
 
-	gmap->x_margin += (width - gmap->width) / 2;
-	gmap->y_margin += (height - gmap->height) / 2;
-
-	gmap->width = width;
-	gmap->height = height;
+	gmap->x_margin = (width - gmap->width) / 2;
+	gmap->y_margin = (height - gmap->height) / 2;
 }
 
 /** @return The radius of the chit for the current font size */
@@ -1128,6 +1112,7 @@ void guimap_display(GuiMap * gmap)
 	PangoContext *pc;
 	PangoFontDescription *pfd;
 	gint font_size;
+	cairo_rectangle_t extents;
 
 	if (gmap->surface == NULL)
 		return;
@@ -1143,7 +1128,8 @@ void guimap_display(GuiMap * gmap)
 				    [BOARD_TILE], 0, 0);
 	cairo_pattern_set_extend(cairo_get_source(gmap->cr),
 				 CAIRO_EXTEND_REPEAT);
-	cairo_rectangle(gmap->cr, 0, 0, gmap->width, gmap->height);
+	cairo_recording_surface_get_extents(gmap->surface, &extents);
+	cairo_rectangle(gmap->cr, 0, 0, extents.width, extents.height);
 	cairo_fill(gmap->cr);
 
 	if (gmap->layout != NULL)
@@ -1205,25 +1191,10 @@ void guimap_zoom_normal(GuiMap * gmap)
 void guimap_zoom_center_map(GuiMap * gmap)
 {
 	GtkAllocation allocation;
-	gint width;
-	gint height;
-
-	if (!gmap->is_custom_view)
-		return;
-	width = gmap->map->x_size * 2 * gmap->x_point + gmap->x_point;
-	if (gmap->map->shrink_left)
-		width -= gmap->x_point;
-	if (gmap->map->shrink_right)
-		width -= gmap->x_point;
 
 	gtk_widget_get_allocation(gmap->area, &allocation);
-	gmap->x_margin = allocation.width / 2 - width / 2;
-
-	height = (gmap->map->y_size - 1) *
-	    (gmap->hex_radius + gmap->y_point)
-	    + 2 * gmap->hex_radius;
-
-	gmap->y_margin = allocation.height / 2 - height / 2;
+	gmap->x_margin = allocation.width / 2 - gmap->width / 2;
+	gmap->y_margin = allocation.height / 2 - gmap->height / 2;
 
 	guimap_display(gmap);
 	gtk_widget_queue_draw(gmap->area);
@@ -1358,7 +1329,7 @@ static void draw_cursor(GuiMap * gmap, gint owner, const Polygon * poly)
 	g_return_if_fail(gmap->cursor.pointer != NULL);
 
 	cairo_set_line_width(gmap->cr, 3.0);
-	gdk_cairo_set_source_color(gmap->cr, colors_get_player(owner));
+	gdk_cairo_set_source_rgba(gmap->cr, colors_get_player(owner));
 	poly_draw_with_border(gmap->cr, &green, poly);
 
 	poly_bound_rect(poly, 1, &rect);
@@ -1583,7 +1554,7 @@ static void draw_robber_cursor(GuiMap * gmap)
 	poly_bound_rect(&poly, 1, &rect);
 
 	cairo_set_line_width(gmap->cr, 2.0);
-	gdk_cairo_set_source_color(gmap->cr, &green);
+	gdk_cairo_set_source_rgba(gmap->cr, &green);
 	poly_draw(gmap->cr, FALSE, &poly);
 
 	gdk_window_invalidate_rect(gtk_widget_get_window(gmap->area),
@@ -1654,23 +1625,23 @@ void guimap_draw_hex(GuiMap * gmap, const Hex * hex)
 }
 
 typedef struct {
-	void (*find) (GuiMap * gmap, MapElement * element);
-	void (*erase_cursor) (GuiMap * gmap);
-	void (*draw_cursor) (GuiMap * gmap);
+	void (*find)(GuiMap * gmap, MapElement * element);
+	void (*erase_cursor)(GuiMap * gmap);
+	void (*draw_cursor)(GuiMap * gmap);
 } ModeCursor;
 
 /* This array must follow the enum CursorType */
 static ModeCursor cursors[] = {
-	{NULL, NULL, NULL},	/* NO_CURSOR */
-	{find_edge, erase_edge_cursor, draw_road_cursor},	/* ROAD_CURSOR */
-	{find_edge, erase_edge_cursor, draw_ship_cursor},	/* SHIP_CURSOR */
-	{find_edge, erase_edge_cursor, draw_bridge_cursor},	/* BRIDGE_CURSOR */
-	{find_node, erase_node_cursor, draw_settlement_cursor},	/* SETTLEMENT_CURSOR */
-	{find_node, erase_node_cursor, draw_city_cursor},	/* CITY_CURSOR */
-	{find_node, erase_node_cursor, draw_city_wall_cursor},	/* CITY_WALL_CURSOR */
-	{find_node, erase_node_cursor, draw_steal_building_cursor},	/* STEAL_BUILDING_CURSOR */
-	{find_edge, erase_edge_cursor, draw_steal_ship_cursor},	/* STEAL_SHIP_CURSOR */
-	{find_hex, erase_robber_cursor, draw_robber_cursor}	/* ROBBER_CURSOR */
+	{ NULL, NULL, NULL },	/* NO_CURSOR */
+	{ find_edge, erase_edge_cursor, draw_road_cursor },	/* ROAD_CURSOR */
+	{ find_edge, erase_edge_cursor, draw_ship_cursor },	/* SHIP_CURSOR */
+	{ find_edge, erase_edge_cursor, draw_bridge_cursor },	/* BRIDGE_CURSOR */
+	{ find_node, erase_node_cursor, draw_settlement_cursor },	/* SETTLEMENT_CURSOR */
+	{ find_node, erase_node_cursor, draw_city_cursor },	/* CITY_CURSOR */
+	{ find_node, erase_node_cursor, draw_city_wall_cursor },	/* CITY_WALL_CURSOR */
+	{ find_node, erase_node_cursor, draw_steal_building_cursor },	/* STEAL_BUILDING_CURSOR */
+	{ find_edge, erase_edge_cursor, draw_steal_ship_cursor },	/* STEAL_SHIP_CURSOR */
+	{ find_hex, erase_robber_cursor, draw_robber_cursor }	/* ROBBER_CURSOR */
 };
 
 gboolean roadM, shipM, bridgeM, settlementM, cityM, cityWallM, shipMoveM;
