@@ -58,9 +58,9 @@ typedef union {
 
 typedef gboolean(*CheckFunc) (const MapElement element, gint owner,
 			      const MapElement user_data);
-typedef void (*SelectFunc) (const MapElement obj,
-			    const MapElement user_data);
-typedef void (*CancelFunc) (void);
+typedef void (*SelectFunc)(const MapElement obj,
+			   const MapElement user_data);
+typedef void (*CancelFunc)(void);
 
 typedef struct _Mode Mode;
 typedef struct {
@@ -91,8 +91,8 @@ typedef struct {
 	gint y_point;		   /**< y offset of node 0 from centre */
 
 	gboolean is_custom_view;   /**< false if all hexes are shown and centered */
-	gint x_margin;		   /**< margin to leave empty */
-	gint y_margin;		   /**< margin to leave empty */
+	gdouble x_margin;	   /**< margin to leave empty */
+	gdouble y_margin;	   /**< margin to leave empty */
 	gint width;		   /**< pixel width of map */
 	gint height;		   /**< pixel height of map */
 	gint player_num;	   /**< player displaying this map */
