@@ -25,8 +25,8 @@ enum {
 static const gint MAP_WIDTH = 64;
 static const gint MAP_HEIGHT = 48;
 
-static void select_game_class_init(SelectGameClass * klass);
-static void select_game_init(SelectGame * sg);
+static void select_game_class_init(gpointer g_class, gpointer class_data);
+static void select_game_init(GTypeInstance * instance, gpointer g_class);
 static void select_game_finalize(GObject * object);
 static void select_game_item_changed(GtkWidget * widget, SelectGame * sg);
 
@@ -43,16 +43,16 @@ GType select_game_get_type(void)
 			sizeof(SelectGameClass),
 			NULL,	/* base_init */
 			NULL,	/* base_finalize */
-			(GClassInitFunc) select_game_class_init,
+			select_game_class_init,
 			NULL,	/* class_finalize */
 			NULL,	/* class_data */
 			sizeof(SelectGame),
 			0,
-			(GInstanceInitFunc) select_game_init,
+			select_game_init,
 			NULL
 		};
 		sg_type =
-		    g_type_register_static(GTK_TYPE_TABLE, "SelectGame",
+		    g_type_register_static(GTK_TYPE_GRID, "SelectGame",
 					   &sg_info, 0);
 	}
 	return sg_type;
@@ -85,13 +85,14 @@ static void select_game_finalize(GObject * object)
  * SelectGame will emit one signal: 'activate' with the text of the
  *    active game in user_data
  */
-static void select_game_class_init(SelectGameClass * klass)
+static void select_game_class_init(gpointer g_class,
+				   G_GNUC_UNUSED gpointer class_data)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS(klass);
+	GObjectClass *object_class = G_OBJECT_CLASS(g_class);
 
 	select_game_signals[ACTIVATE] = g_signal_new("activate",
 						     G_TYPE_FROM_CLASS
-						     (klass),
+						     (g_class),
 						     G_SIGNAL_RUN_FIRST |
 						     G_SIGNAL_ACTION,
 						     G_STRUCT_OFFSET
@@ -104,9 +105,11 @@ static void select_game_class_init(SelectGameClass * klass)
 }
 
 /* Build the composite widget */
-static void select_game_init(SelectGame * sg)
+static void select_game_init(GTypeInstance * instance,
+			     G_GNUC_UNUSED gpointer g_class)
 {
 	GtkCellRenderer *cell;
+	SelectGame *sg = SELECTGAME(instance);
 
 	/* Create model */
 	sg->data =
@@ -133,9 +136,7 @@ static void select_game_init(SelectGame * sg)
 	gtk_widget_set_tooltip_text(sg->combo_box,
 				    /* Tooltip for the list of games */
 				    _("Select a game"));
-	gtk_table_resize(GTK_TABLE(sg), 1, 1);
-	gtk_table_attach_defaults(GTK_TABLE(sg), sg->combo_box,
-				  0, 1, 0, 1);
+	gtk_grid_attach(GTK_GRID(sg), sg->combo_box, 0, 0, 1, 1);
 	sg->default_game = g_strdup("Default");
 	g_signal_connect(G_OBJECT(sg->combo_box), "changed",
 			 G_CALLBACK(select_game_item_changed), sg);
@@ -213,8 +214,8 @@ static GdkPixbuf *render_map(GtkWidget * base_widget, const Map * map)
 	guimap_display(gmap);
 
 	pixbuf =
-	    gdk_pixbuf_get_from_surface(gmap->surface, 0, 0, gmap->width,
-					gmap->height);
+	    gdk_pixbuf_get_from_surface(gmap->surface, 0, 0, MAP_WIDTH,
+					MAP_HEIGHT);
 	guimap_delete(gmap);
 
 	return pixbuf;
