@@ -5,7 +5,7 @@
  * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2011 Micah Bunting <Amnykon@gmail.com>
  * Copyright (C) 2011 Roland Clobus <rclobus@rclobus.nl>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -64,7 +64,7 @@
  */
 
 /* The accessor functions:
- 
+
  *              /\               *
  *             /  \              *
  *            /    \             *
@@ -591,6 +591,7 @@ static gboolean layout_chits(Map * map)
 			if (hexes[hex->chit_pos] != NULL) {
 				g_warning("Sequence number %d used again",
 					  hex->chit_pos);
+				g_free(hexes);
 				return FALSE;
 			}
 			hexes[hex->chit_pos] = hex;
@@ -600,6 +601,7 @@ static gboolean layout_chits(Map * map)
 	if (num_chits < map->chits->len + num_deserts) {
 		g_warning("More chits (%u + %u) than available tiles (%u)",
 			  map->chits->len, num_deserts, num_chits);
+		g_free(hexes);
 		return FALSE;
 	}
 	/* If less chits are defined than tiles that need chits,
@@ -779,7 +781,7 @@ static Hex *hex_new(Map * map, gint x, gint y)
 /** Copy a hex.
  * @param map The new owner
  * @param hex The original hex
- * @return A copy of the original hex, with the new owner. 
+ * @return A copy of the original hex, with the new owner.
  *         The copy is not connected (nodes and edges are NULL)
 */
 static Hex *copy_hex(Map * map, const Hex * hex)
@@ -1094,6 +1096,7 @@ gboolean map_parse_line(Map * map, const gchar * line)
 		if (hex->chit_pos < 0 && hex->terrain != SEA_TERRAIN) {
 			g_warning
 			    ("Land tile without chit sequence number");
+			g_free(hex);
 			return FALSE;
 		}
 
