@@ -28,6 +28,11 @@
 #include "network.h"
 #include "log.h"
 
+/* Add support for versions of glib before 2.58 */
+#ifndef G_SOURCE_FUNC
+#define G_SOURCE_FUNC(f) ((GSourceFunc) (void (*)(void)) (f))
+#endif
+
 struct _Service {
 	GSocketListener *listener;
 	GCancellable *cancellable;
@@ -351,8 +356,8 @@ static void net_start_listening(Session * ses)
 						   (G_IO_STREAM
 						    (ses->connection))),
 						  ses->input_cancel);
-	g_source_set_callback(input_source, (GSourceFunc) input_ready, ses,
-			      NULL);
+	g_source_set_callback(input_source, G_SOURCE_FUNC(input_ready),
+			      ses, NULL);
 	g_source_attach(input_source, NULL);
 	g_source_unref(input_source);
 }
