@@ -2,7 +2,7 @@
  *   Go buy a copy.
  *
  * Copyright (C) 2005 Brian Wellington
- * Copyright (C) 2005,2011 Roland Clobus
+ * Copyright (C) 2005,2011,2020 Roland Clobus
  * Copyright (C) 2005,2006 Bas Wijnen
  * Copyright (C) 2011-2013 Micah Bunting <Amnykon@gmail.com>
  *
@@ -23,11 +23,8 @@
 #include "config.h"
 #include "version.h"
 
-#ifdef HAVE_LOCALE_H
-#include <locale.h>
-#endif
-
 #include <string.h>
+#include <sys/stat.h>
 #include "aboutbox.h"
 #include "config-gnome.h"
 #include "game.h"
@@ -44,6 +41,7 @@
 #include "common_gtk.h"
 #include "cards.h"
 #include "network.h"
+#include "gettext.h"
 
 #define MAINICON_FILE "pioneers-editor.png"
 
@@ -53,6 +51,26 @@
 #define BUTTON_HEIGHT 24	/* height of the toolbar buttons */
 #define TERRAIN_BUTTON_WIDTH 27	/* width of the terrain toolbar buttons */
 
+/* Callback functions from the resource file */
+G_MODULE_EXPORT void new_game_menu_cb(GObject * gobject,
+				      gpointer user_data);
+G_MODULE_EXPORT void load_game_menu_cb(GObject * gobject,
+				       gpointer user_data);
+G_MODULE_EXPORT void save_as_menu_cb(GObject * gobject,
+				     gpointer user_data);
+G_MODULE_EXPORT void save_game_menu_cb(GObject * gobject,
+				       gpointer user_data);
+G_MODULE_EXPORT void change_title_menu_cb(GObject * gobject,
+					  gpointer user_data);
+G_MODULE_EXPORT void check_vp_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void exit_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void about_menu_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void toggle_full_screen_cb(GObject * gobject,
+					   gpointer user_data);
+G_MODULE_EXPORT void zoom_normal_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void zoom_center_map_cb(GObject * gobject,
+					gpointer user_data);
+
 static GtkWidget *toplevel;
 static gchar *default_game;
 static gchar *window_title;
@@ -161,7 +179,6 @@ static const gchar *port_direction_names[] = {
 	N_("South East|SE")
 };
 
-static void check_vp_cb(GObject * caller, gpointer main_window);
 static void set_window_title(const gchar * title);
 
 static void error_dialog(const char *fmt, ...)
@@ -206,6 +223,15 @@ static void fill_map(Map * map)
 	}
 }
 
+static gboolean terrain_has_chit(Terrain terrain)
+{
+	if (terrain == HILL_TERRAIN || terrain == FIELD_TERRAIN ||
+	    terrain == MOUNTAIN_TERRAIN || terrain == PASTURE_TERRAIN ||
+	    terrain == FOREST_TERRAIN || terrain == GOLD_TERRAIN)
+		return TRUE;
+	return FALSE;
+}
+
 static void canonicalize_map(Map * map)
 {
 	Hex *hex;
@@ -221,25 +247,25 @@ static void canonicalize_map(Map * map)
 			hex = map->grid[y][x];
 			if (hex == NULL)
 				continue;
-			if (hex->roll > 0) {
+			if (terrain_has_chit(hex->terrain)) {
+				if (hex->roll <= 0) {
+					/* Should not happen, but we do not want to throw away the work of the user, so correct and continue */
+					g_warning
+					    ("The dice roll is corrected for hex %d,%d",
+					     hex->x, hex->y);
+					hex->roll = 2;
+				}
 				g_array_append_val(map->chits, hex->roll);
 				hex->chit_pos = sequence_number++;
 			} else if (hex->terrain == DESERT_TERRAIN) {
 				hex->chit_pos = sequence_number++;
+			} else {
+				hex->chit_pos = -1;
 			}
 		}
 	}
 }
 
-static gboolean terrain_has_chit(Terrain terrain)
-{
-	if (terrain == HILL_TERRAIN || terrain == FIELD_TERRAIN ||
-	    terrain == MOUNTAIN_TERRAIN || terrain == PASTURE_TERRAIN ||
-	    terrain == FOREST_TERRAIN || terrain == GOLD_TERRAIN)
-		return TRUE;
-	return FALSE;
-}
-
 /** Changes the terrain of a hex to terrain.
  * @param hex The hex to change the terrain of.
  * @param terrain The terrain to change the hex terrain to.
@@ -253,14 +279,13 @@ static void change_terrain(Hex * hex, Terrain terrain)
 		return;
 
 	hex->terrain = terrain;
-	if (terrain_has_chit(terrain)) {
-		if (hex->roll == 0)
-			hex->roll = 2;
-	} else
+	if (terrain_has_chit(terrain) && (hex->roll == 0)) {
+		hex->roll = 2;
+	} else {
 		hex->roll = 0;
-
-	if (terrain != SEA_TERRAIN)
-		hex->resource = NO_RESOURCE;
+	}
+	hex->resource = NO_RESOURCE;
+	hex->facing = 0;
 
 	/* If terrain is not land,
 	 * remove all ports on adjacent hexes that point to hex */
@@ -293,8 +318,8 @@ static gboolean draw_chit_cb(GtkWidget * widget, cairo_t * cr,
 
 	layout = gtk_widget_create_pango_layout(widget, "");
 	draw_dice_roll(layout, cr,
-		       12, 10, 15, GPOINTER_TO_INT(chip_number),
-		       GOLD_TERRAIN, FALSE);
+		       BUTTON_HEIGHT / 2, BUTTON_HEIGHT / 2, BUTTON_HEIGHT,
+		       GPOINTER_TO_INT(chip_number), SEA_TERRAIN, FALSE);
 	g_object_unref(layout);
 	return TRUE;
 }
@@ -319,15 +344,18 @@ static gboolean draw_port_cb(GtkWidget * widget, cairo_t * cr,
 	width = gdk_pixbuf_get_width(theme->terrain_tiles[SEA_TERRAIN]);
 	height = gdk_pixbuf_get_height(theme->terrain_tiles[SEA_TERRAIN]);
 	gdk_cairo_set_source_pixbuf(cr, theme->terrain_tiles[SEA_TERRAIN],
-				    BUTTON_HEIGHT / 2 - width / 2,
-				    BUTTON_HEIGHT / 2 - height / 2);
+				    gtk_widget_get_allocated_width(widget)
+				    / 2 - width / 2,
+				    gtk_widget_get_allocated_height(widget)
+				    / 2 - height / 2);
 	cairo_pattern_set_extend(cairo_get_source(cr),
 				 CAIRO_EXTEND_REPEAT);
 	cairo_paint(cr);
 
-	draw_port_indicator(layout, cr, BUTTON_HEIGHT / 2,
-			    BUTTON_HEIGHT / 2, 11,
-			    GPOINTER_TO_INT(port_type));
+	draw_port_indicator(layout, cr,
+			    gtk_widget_get_allocated_width(widget) / 2,
+			    gtk_widget_get_allocated_height(widget) / 2,
+			    11, GPOINTER_TO_INT(port_type));
 	g_object_unref(layout);
 
 	return TRUE;
@@ -343,7 +371,7 @@ static gboolean draw_unselect_cb(G_GNUC_UNUSED GtkWidget * widget,
 				 cairo_t * cr,
 				 G_GNUC_UNUSED gpointer user_data)
 {
-	gdk_cairo_set_source_color(cr, &white);
+	gdk_cairo_set_source_rgba(cr, &white);
 	cairo_paint(cr);
 
 	return TRUE;
@@ -408,20 +436,26 @@ static const gchar *PORT_TOOLBAR_TOOLTIP[] = {
 };
 
 /** Builds toolbars for selecting terrains, chits, and ports. Places toolbar in
- * the table at the top.
- * @param table The table to place toolbar in.
+ * the grid at the top.
+ * @param grid The grid to place the toolbar in.
  */
-static void build_select_bars(GtkWidget * table)
+static void build_select_bars(GtkWidget * grid)
 {
+	GtkWidget *flowbox;
 	GtkWidget *box;
 	GtkWidget *area;
 	GtkWidget *button;
 	GSList *group;
-	GtkWidget *vsep;
 	gint i;
 	ToolbarButtonData *toolbar_button_data;
 
-	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);	/* upper bar */
+	flowbox = gtk_flow_box_new();
+	gtk_flow_box_set_column_spacing(GTK_FLOW_BOX(flowbox), 10);
+	gtk_flow_box_set_homogeneous(GTK_FLOW_BOX(flowbox), FALSE);
+	gtk_flow_box_set_selection_mode(GTK_FLOW_BOX(flowbox),
+					GTK_SELECTION_NONE);
+
+	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	area = gtk_drawing_area_new();
 	gtk_widget_show(area);
@@ -433,6 +467,7 @@ static void build_select_bars(GtkWidget * table)
 	button = GTK_WIDGET(gtk_radio_tool_button_new(NULL));
 	gtk_tool_button_set_icon_widget(GTK_TOOL_BUTTON(button), area);
 	gtk_box_pack_start(GTK_BOX(box), button, FALSE, TRUE, 0);
+	gtk_widget_set_margin_end(button, 10);
 	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(button), _
 				       ("Select the terrain type with the context "
 					"menu on the left click or toggle a node to "
@@ -450,12 +485,6 @@ static void build_select_bars(GtkWidget * table)
 	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(button),
 					  TRUE);
 
-	/* Line between unselect and terrains */
-	vsep = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
-	gtk_widget_show(vsep);
-	gtk_widget_set_size_request(vsep, 10, 0);
-	gtk_box_pack_start(GTK_BOX(box), vsep, FALSE, TRUE, 0);
-
 	/* terrain toolbar buttons */
 	for (i = 0; i <= LAST_TERRAIN; i++) {
 		area = terrain_icon_new(i);
@@ -481,10 +510,9 @@ static void build_select_bars(GtkWidget * table)
 
 	}
 
-	gtk_table_attach(GTK_TABLE(table), box, 0, 2, 0, 1,
-			 GTK_FILL, GTK_FILL, 0, 0);
+	gtk_container_add(GTK_CONTAINER(flowbox), box);
 
-	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);	/* lower bar */
+	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	/* chit toolbar buttons */
 	for (i = 2; i <= 12; i++) {
@@ -519,11 +547,9 @@ static void build_select_bars(GtkWidget * table)
 				 toolbar_button_data);
 	}
 
-	/* Line between chit and port */
-	vsep = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
-	gtk_widget_show(vsep);
-	gtk_widget_set_size_request(vsep, 10, 0);
-	gtk_box_pack_start(GTK_BOX(box), vsep, FALSE, TRUE, 0);
+	gtk_container_add(GTK_CONTAINER(flowbox), box);
+
+	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	/* port toolbar buttons */
 	for (i = 0; i <= ANY_RESOURCE; i++) {
@@ -556,11 +582,14 @@ static void build_select_bars(GtkWidget * table)
 				 toolbar_button_data);
 	}
 
-	gtk_table_attach(GTK_TABLE(table), box, 0, 2, 1, 2,
-			 GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand(box, TRUE);	/* Fill remaining space */
+	gtk_container_add(GTK_CONTAINER(flowbox), box);
+
+	gtk_widget_set_hexpand(flowbox, TRUE);	/* Fill remaining space */
+	gtk_grid_attach(GTK_GRID(grid), flowbox, 0, 0, 2, 1);
 }
 
-static void build_map_resize(GtkWidget * table, guint col, guint row,
+static void build_map_resize(GtkWidget * grid, gint col, gint row,
 			     GtkOrientation dir, GtkWidget ** buttons,
 			     GCallback resize_callback)
 {
@@ -602,8 +631,7 @@ static void build_map_resize(GtkWidget * table, guint col, guint row,
 	}
 	gtk_box_pack_start(GTK_BOX(box), gtk_fixed_new(), TRUE, TRUE, 0);
 
-	gtk_table_attach(GTK_TABLE(table), box, col, col + 1, row, row + 1,
-			 GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(grid), box, col, row, 1, 1);
 }
 
 static void scale_map(GuiMap * gmap)
@@ -621,7 +649,7 @@ static gboolean enter_notify_map_cb(GtkWidget * widget,
 {
 	if (event->mode != GDK_CROSSING_GTK_UNGRAB) {
 		/* Do not grab the focus when a ScrollableTextView
-		 * is focussed on another tab page */
+		 * is focused on another tab page */
 		gtk_widget_grab_focus(widget);
 	}
 	return FALSE;
@@ -641,6 +669,8 @@ static gint button_press_map_cb(GtkWidget * area,
 	if (gtk_widget_get_window(area) == NULL || gmap->map == NULL)
 		return FALSE;
 
+	gmap->last_x = event->x;
+	gmap->last_y = event->y;
 	current_hex = guimap_get_current_hex(gmap);
 	if (current_hex == NULL)
 		return TRUE;
@@ -764,9 +794,10 @@ static gint button_press_map_cb(GtkWidget * area,
 			menu = port_menu;
 	}
 
-	if (menu != NULL)
-		gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
-			       event->button, event->time);
+	if (menu != NULL) {
+		gtk_menu_popup_at_pointer(GTK_MENU(menu),
+					  (GdkEvent *) event);
+	}
 
 	return TRUE;
 }
@@ -925,10 +956,10 @@ static void change_width(G_GNUC_UNUSED GtkWidget * menu,
 
 static GtkWidget *build_map(void)
 {
-	GtkWidget *table;
+	GtkWidget *grid;
 	GtkWidget *area;
 
-	table = gtk_table_new(4, 2, FALSE);
+	grid = gtk_grid_new();
 
 	gmap = guimap_new();
 	guimap_set_show_no_setup_nodes(gmap, TRUE);
@@ -944,17 +975,17 @@ static GtkWidget *build_map(void)
 			 G_CALLBACK(button_press_map_cb), gmap);
 	g_signal_connect(G_OBJECT(gmap->area), "key_press_event",
 			 G_CALLBACK(key_press_map_cb), gmap);
-	gtk_table_attach(GTK_TABLE(table), gmap->area, 0, 1, 2, 3,
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
-			 0);
+	gtk_grid_attach(GTK_GRID(grid), gmap->area, 0, 1, 1, 1);
+	gtk_widget_set_hexpand(gmap->area, TRUE);
+	gtk_widget_set_vexpand(gmap->area, TRUE);
 
-	build_select_bars(table);
-	build_map_resize(table, 1, 2, GTK_ORIENTATION_VERTICAL,
+	build_select_bars(grid);
+	build_map_resize(grid, 1, 1, GTK_ORIENTATION_VERTICAL,
 			 vresize_buttons, G_CALLBACK(change_height));
-	build_map_resize(table, 0, 3, GTK_ORIENTATION_HORIZONTAL,
+	build_map_resize(grid, 0, 2, GTK_ORIENTATION_HORIZONTAL,
 			 hresize_buttons, G_CALLBACK(change_width));
 
-	return table;
+	return grid;
 }
 
 static gboolean update_title(GtkWidget * widget,
@@ -977,7 +1008,7 @@ static GtkWidget *build_comments(void)
 	/* Label */
 	widget = gtk_label_new_with_mnemonic(_("_Title"));
 	gtk_widget_show(widget);
-	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(widget), 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
 
 	game_title = gtk_entry_new();
@@ -990,7 +1021,7 @@ static GtkWidget *build_comments(void)
 	/* Label */
 	widget = gtk_label_new_with_mnemonic(_("_Description"));
 	gtk_widget_show(widget);
-	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(widget), 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
 
 	game_description = scrollable_text_view_new();
@@ -1008,7 +1039,7 @@ static GtkWidget *build_comments(void)
 	/* Label */
 	widget = gtk_label_new_with_mnemonic(_("_Comments"));
 	gtk_widget_show(widget);
-	gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(widget), 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
 
 	game_comments = scrollable_text_view_new();
@@ -1035,45 +1066,32 @@ static GtkWidget *build_terrain_menu(void)
 	gint i;
 	GtkWidget *menu;
 	GtkWidget *item;
-	GdkPixbuf *pixbuf;
+	GtkWidget *box;
 	GtkWidget *image;
-	gint width;
-	gint height;
-	MapTheme *theme = theme_get_current();
+	GtkWidget *label;
 
 	menu = gtk_menu_new();
 
 	for (i = 0; i <= LAST_TERRAIN; i++) {
-		item =
-		    gtk_image_menu_item_new_with_mnemonic(gettext
-							  (terrain_names
-							   [i]));
+		item = gtk_menu_item_new();
+		box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+		label =
+		    gtk_label_new_with_mnemonic(gettext(terrain_names[i]));
+		if (i == LAST_TERRAIN) {
+			image = gtk_drawing_area_new();
+		} else {
+			image = terrain_icon_new(i);
+		}
+		gtk_widget_set_size_request(image, BUTTON_HEIGHT,
+					    BUTTON_HEIGHT);
+		gtk_container_add(GTK_CONTAINER(box), image);
+		gtk_container_add(GTK_CONTAINER(box), label);
+		gtk_container_add(GTK_CONTAINER(item), box);
 
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 		g_signal_connect(G_OBJECT(item), "activate",
 				 G_CALLBACK(select_terrain_cb),
 				 GINT_TO_POINTER(i));
-
-		if (i == LAST_TERRAIN)
-			continue;
-
-		/* Use the default size, or smaller */
-		gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
-		if (height > width / theme->scaledata[i].aspect) {
-			height = width / theme->scaledata[i].aspect;
-		} else {
-			width = height * theme->scaledata[i].aspect;
-		}
-
-		pixbuf =
-		    gdk_pixbuf_scale_simple(theme->
-					    scaledata[i].native_image,
-					    width, height,
-					    GDK_INTERP_BILINEAR);
-
-		image = gtk_image_new_from_pixbuf(pixbuf);
-		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-					      image);
 	}
 
 	gtk_widget_show_all(menu);
@@ -1102,7 +1120,8 @@ static GtkWidget *build_roll_menu(void)
 	gchar buffer[128];
 	MapTheme *theme = theme_get_current();
 	THEME_COLOR tcolor;
-	GdkColor *color;
+	GdkRGBA *colorFG;
+	GdkRGBA *colorBG;
 	GtkWidget *item;
 	GtkWidget *label;
 
@@ -1113,10 +1132,23 @@ static GtkWidget *build_roll_menu(void)
 			continue;
 
 		tcolor = (i == 6 || i == 8) ? TC_CHIP_H_FG : TC_CHIP_FG;
-		color = &theme->colors[tcolor].color;
+		colorFG =
+		    theme->ovr_colors[SEA_TERRAIN][tcolor].
+		    set ? &theme->ovr_colors[SEA_TERRAIN][tcolor].
+		    color : &theme->colors[tcolor].color;
+		tcolor = TC_CHIP_BG;
+		colorBG =
+		    theme->ovr_colors[SEA_TERRAIN][tcolor].
+		    set ? &theme->ovr_colors[SEA_TERRAIN][tcolor].
+		    color : &theme->colors[tcolor].color;
 		sprintf(buffer,
-			"<span foreground=\"#%04x%04x%04x\">%d</span>",
-			color->red, color->green, color->blue, i);
+			"<span foreground=\"#%04x%04x%04x\" background=\"#%04x%04x%04x\">%d</span>",
+			(unsigned) (colorFG->red * 255 * 256),
+			(unsigned) (colorFG->green * 255 * 256),
+			(unsigned) (colorFG->blue * 255 * 256),
+			(unsigned) (colorBG->red * 255 * 256),
+			(unsigned) (colorBG->green * 255 * 256),
+			(unsigned) (colorBG->blue * 255 * 256), i);
 
 		item = gtk_check_menu_item_new();
 		label = gtk_label_new("");
@@ -1182,32 +1214,33 @@ static GtkWidget *build_port_menu(void)
 {
 	gint i;
 	GtkWidget *item;
-	GdkPixbuf *pixbuf;
+	GtkWidget *box;
 	GtkWidget *image;
+	GtkWidget *label;
 	GtkWidget *menu;
-	MapTheme *theme = theme_get_current();
 
 	menu = gtk_menu_new();
 
 	for (i = 0; i <= ANY_RESOURCE; i++) {
-		item =
-		    gtk_image_menu_item_new_with_mnemonic(gettext
-							  (port_names[i]));
+		item = gtk_menu_item_new();
+		box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
+		label =
+		    gtk_label_new_with_mnemonic(gettext(port_names[i]));
+
+		image = gtk_drawing_area_new();
+		gtk_widget_set_size_request(image, BUTTON_HEIGHT,
+					    BUTTON_HEIGHT);
+		g_signal_connect(G_OBJECT(image), "draw",
+				 G_CALLBACK(draw_port_cb),
+				 GINT_TO_POINTER(i));
+		gtk_container_add(GTK_CONTAINER(box), image);
+		gtk_container_add(GTK_CONTAINER(box), label);
+		gtk_container_add(GTK_CONTAINER(item), box);
 
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 		g_signal_connect(G_OBJECT(item), "activate",
 				 G_CALLBACK(select_port_resource_cb),
 				 GINT_TO_POINTER(i));
-
-		if (i >= NO_RESOURCE)
-			continue;
-		pixbuf = theme->port_tiles[i];
-		if (pixbuf == NULL)
-			continue;
-
-		image = gtk_image_new_from_pixbuf(pixbuf);
-		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-					      image);
 	}
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu),
 			      gtk_separator_menu_item_new());
@@ -1432,6 +1465,8 @@ static void load_game(const gchar * file, gboolean is_reload)
 	params = params_load_file(gamefile);
 	if (params == NULL) {
 		error_dialog(_("Failed to load '%s'"), file);
+		if (!is_reload)
+			load_game(NULL, TRUE);
 		return;
 	}
 
@@ -1477,15 +1512,25 @@ static void load_game(const gchar * file, gboolean is_reload)
 static void save_game(const gchar * file)
 {
 	GameParams *params = get_params();
+	GameParams *reloaded_params;
 	canonicalize_map(params->map);
 	if (!params_write_file(params, file))
 		error_dialog(_("Failed to save to '%s'"), file);
-	else
-		config_set_string("editor/last-game", file);
+	else {
+		reloaded_params = params_load_file(file);
+		if (reloaded_params != NULL) {
+			config_set_string("editor/last-game", file);
+		} else {
+			error_dialog
+			    ("You found a bug.The saved game could not be loaded.");
+		}
+		params_free(reloaded_params);
+	}
 	params_free(params);
 }
 
-static void new_game_menu_cb(void)
+void new_game_menu_cb(G_GNUC_UNUSED GObject * gobject,
+		      G_GNUC_UNUSED gpointer user_data)
 {
 	load_game(NULL, TRUE);
 }
@@ -1507,7 +1552,25 @@ static void add_file_filter(GtkFileChooser * file_chooser)
 	gtk_file_chooser_add_filter(file_chooser, filter);
 }
 
-static void load_game_menu_cb(void)
+static gchar *prepare_local_games_folder(void)
+{
+	gchar *directory;
+
+	if (g_strcmp0(g_get_user_data_dir(), g_get_user_config_dir()) == 0) {
+		directory =
+		    g_build_filename(g_get_user_data_dir(),
+				     "pioneers_games", NULL);
+	} else {
+		directory =
+		    g_build_filename(g_get_user_data_dir(), "pioneers",
+				     NULL);
+	}
+	g_mkdir_with_parents(directory, S_IRWXU);
+
+	return directory;
+}
+
+void load_game_menu_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
 	GtkWidget *dialog;
 	gchar *directory;
@@ -1515,7 +1578,7 @@ static void load_game_menu_cb(void)
 	dialog = gtk_file_chooser_dialog_new(
 						    /* Dialog caption */
 						    _("Open Game"),
-						    GTK_WINDOW(toplevel),
+						    GTK_WINDOW(user_data),
 						    GTK_FILE_CHOOSER_ACTION_OPEN,
 						    /* Button text */
 						    _("_Cancel"),
@@ -1523,8 +1586,7 @@ static void load_game_menu_cb(void)
 						    /* Button text */
 						    _("_Open"),
 						    GTK_RESPONSE_OK, NULL);
-	directory =
-	    g_build_filename(g_get_user_data_dir(), "pioneers", NULL);
+	directory = prepare_local_games_folder();
 	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
 					    directory);
 	gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(dialog),
@@ -1548,7 +1610,7 @@ static void load_game_menu_cb(void)
 	gtk_widget_destroy(dialog);
 }
 
-static void save_as_menu_cb(void)
+void save_as_menu_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
 	GtkWidget *dialog;
 	gchar *directory;
@@ -1556,7 +1618,7 @@ static void save_as_menu_cb(void)
 	dialog = gtk_file_chooser_dialog_new(
 						    /* Dialog caption */
 						    _("Save As..."),
-						    GTK_WINDOW(toplevel),
+						    GTK_WINDOW(user_data),
 						    GTK_FILE_CHOOSER_ACTION_SAVE,
 						    /* Button text */
 						    _("_Cancel"),
@@ -1565,8 +1627,7 @@ static void save_as_menu_cb(void)
 						    _("Save _As"),
 						    GTK_RESPONSE_ACCEPT,
 						    NULL);
-	directory =
-	    g_build_filename(g_get_user_data_dir(), "pioneers", NULL);
+	directory = prepare_local_games_folder();
 	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog),
 					    directory);
 	gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(dialog),
@@ -1589,22 +1650,23 @@ static void save_as_menu_cb(void)
 	gtk_widget_destroy(dialog);
 }
 
-static void save_game_menu_cb(void)
+void save_game_menu_cb(GObject * gobject, gpointer user_data)
 {
 	if (open_filename == NULL)
-		save_as_menu_cb();
+		save_as_menu_cb(gobject, user_data);
 	else
 		save_game(open_filename);
 }
 
-static void change_title_menu_cb(void)
+void change_title_menu_cb(G_GNUC_UNUSED GObject * gobject,
+			  gpointer user_data)
 {
 	GtkWidget *dialog, *vbox, *hbox, *label, *entry;
 
 	dialog = gtk_dialog_new_with_buttons(
 						    /* Dialog caption */
 						    _("Change Title"),
-						    GTK_WINDOW(toplevel),
+						    GTK_WINDOW(user_data),
 						    GTK_DIALOG_MODAL |
 						    GTK_DIALOG_DESTROY_WITH_PARENT,
 						    /* Button text */
@@ -1630,7 +1692,7 @@ static void change_title_menu_cb(void)
 	/* Label */
 	label = gtk_label_new(_("New title:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, TRUE, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 
 	/* Update the window_title before is it shown */
 	set_window_title(gtk_entry_get_text(GTK_ENTRY(game_title)));
@@ -1648,212 +1710,73 @@ static void change_title_menu_cb(void)
 	gtk_widget_destroy(dialog);
 }
 
-static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
-			gpointer main_window)
+void check_vp_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
 	GameParams *params;
 
 	params = get_params();
-	check_victory_points(params, main_window);
+	check_victory_points(params, GTK_WINDOW(user_data));
 	params_free(params);
 }
 
-static void exit_cb(void)
+void exit_cb(G_GNUC_UNUSED GObject * gobject,
+	     G_GNUC_UNUSED gpointer user_data)
 {
 	gtk_main_quit();
 }
 
-#ifdef HAVE_HELP
-/* Commented out, until the help is written
-static void contents_menu_cb(void)
+void about_menu_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
-	GtkWidget *dialog;
-
-	dialog = gtk_message_dialog_new(GTK_WINDOW(toplevel),
-					GTK_DIALOG_MODAL |
-					GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_WARNING,
-					GTK_BUTTONS_CLOSE,
-					_("There is no help"));
-	gtk_dialog_run(GTK_DIALOG(dialog));
-	gtk_widget_destroy(dialog);
-}
-*/
-#endif
-
-static void about_menu_cb(void)
-{
-	aboutbox_display(GTK_WINDOW(toplevel),
+	aboutbox_display(GTK_WINDOW(user_data),
 			 /* Caption of about box */
 			 _("About Pioneers Game Editor"));
 }
 
 /** Toggles full screen mode.
- * @param GtkToggleAction The calling action.
- * @param main_window The window to toggle full screen mode.
 */
-static void toggle_full_screen_cb(GtkToggleAction * caller,
-				  gpointer main_window)
+void toggle_full_screen_cb(GObject * gobject, gpointer user_data)
 {
-	if (gtk_toggle_action_get_active(caller)) {
-		gtk_window_fullscreen(GTK_WINDOW(main_window));
+	if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(gobject))) {
+		gtk_window_fullscreen(GTK_WINDOW(user_data));
 	} else {
-		gtk_window_unfullscreen(GTK_WINDOW(main_window));
+		gtk_window_unfullscreen(GTK_WINDOW(user_data));
 	}
 }
 
-static void zoom_normal_cb(void)
+void zoom_normal_cb(G_GNUC_UNUSED GObject * gobject,
+		    G_GNUC_UNUSED gpointer user_data)
 {
 	guimap_zoom_normal(gmap);
 }
 
-static void zoom_center_map_cb(void)
+void zoom_center_map_cb(G_GNUC_UNUSED GObject * gobject,
+			G_GNUC_UNUSED gpointer user_data)
 {
 	guimap_zoom_center_map(gmap);
 }
 
-static GtkActionEntry entries[] = {
-	{"FileMenu", NULL,
-	 /* Menu entry */
-	 N_("_File"), NULL, NULL, NULL},
-	{"ViewMenu", NULL,
-	 /* Menu entry */
-	 N_("_View"), NULL, NULL, NULL},
-	{"HelpMenu", NULL,
-	 /* Menu entry */
-	 N_("_Help"), NULL, NULL, NULL},
-
-	{"New", NULL,
-	 /* Menu entry */
-	 N_("_New"), "<control>N",
-	 N_("Create a new game"), new_game_menu_cb},
-	{"Open", NULL,
-	 /* Menu entry */
-	 N_("_Open..."), "<control>O",
-	 /* Tooltip for Open menu entry */
-	 N_("Open an existing game"), load_game_menu_cb},
-	{"Save", NULL,
-	 /* Menu entry */
-	 N_("_Save"), "<control>S",
-	 /* Tooltip for Save menu entry */
-	 N_("Save game"), save_game_menu_cb},
-	{"SaveAs", NULL,
-	 /* Menu entry */
-	 N_("Save _As..."),
-	 "<control><shift>S",
-	 /* Tooltip for Save As menu entry */
-	 N_("Save as"), save_as_menu_cb},
-	{"ChangeTitle", NULL,
-	 /* Menu entry */
-	 N_("Change _Title"), "<control>T",
-	 /* Tooltip for Change Title menu entry */
-	 N_("Change game title"), change_title_menu_cb},
-	{"CheckVP", NULL,
-	 /* Menu entry */
-	 N_("_Check Victory Point Target"),
-	 NULL,
-	 /* Tooltip for Check Victory Point Target menu entry */
-	 N_("Check whether the game can be won"), G_CALLBACK(check_vp_cb)},
-	{"Quit", NULL,
-	 /* Menu entry */
-	 N_("_Quit"), "<control>Q",
-	 /* Tooltip for Quit menu entry */
-	 N_("Quit"), exit_cb},
-
-	{"Full", NULL,
-	 /* Menu entry */
-	 N_("_Reset"),
-	 "<control>0",
-	 /* Tooltip for Reset menu entry */
-	 N_("View the full map"), zoom_normal_cb},
-	{"Center", NULL,
-	 /* Menu entry */
-	 N_("_Center"), NULL,
-	 /* Tooltip for Center menu entry */
-	 N_("Center the map"), zoom_center_map_cb},
-
-#ifdef HAVE_HELP
-	/* Disable this item, until the help is written
-	   {"Contents", NULL, N_("_Contents"), "F1",
-	   N_("Contents"), contents_menu_cb},
-	 */
-#endif
-	{"About", NULL,
-	 /* Menu entry */
-	 N_("_About Pioneers Editor"), NULL,
-	 /* Tooltip for About Pioneers Editor menu entry */
-	 N_("Information about Pioneers Editor"), about_menu_cb},
-};
-
-static GtkToggleActionEntry toggle_entries[] = {
-	{"FullScreen", NULL,
-	 /* Menu entry */
-	 N_("_Fullscreen"),
-	 "<alt>Return",
-	 /* Tooltip for Fullscreen menu entry */
-	 N_("Set window to full screen mode"),
-	 G_CALLBACK(toggle_full_screen_cb), FALSE}
-};
-
-/* *INDENT-OFF* */
-static const char *ui_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='FileMenu'>"
-"      <menuitem action='New'/>"
-"      <menuitem action='Open'/>"
-"      <menuitem action='Save'/>"
-"      <menuitem action='SaveAs'/>"
-"      <separator/>"
-"      <menuitem action='CheckVP'/>"
-"      <menuitem action='ChangeTitle'/>"
-"      <separator/>"
-"      <menuitem action='Quit'/>"
-"    </menu>"
-"    <menu action='ViewMenu'>"
-"      <menuitem action='FullScreen'/>"
-"      <menuitem action='Full'/>"
-"      <menuitem action='Center'/>"
-"    </menu>"
-"    <menu action='HelpMenu'>"
-#ifdef HAVE_HELP
-/* Disable this menu item, until the help is written
-"      <menuitem action='Contents'/>"
-"      <separator/>"
-*/
-#endif
-"      <menuitem action='About'/>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-/* *INDENT-ON* */
-
 gchar **filenames;
 gboolean show_version = FALSE;
 
 static GOptionEntry commandline_entries[] = {
-	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY,
+	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY,
 	 &filenames,
 	 /* Long help for commandline option (editor): filename */
 	 N_("Open this file"),
 	 /* Commandline option for editor: filename */
-	 N_("filename")},
-	{"version", '\0', 0, G_OPTION_ARG_NONE, &show_version,
+	 N_("filename") },
+	{ "version", '\0', 0, G_OPTION_ARG_NONE, &show_version,
 	 /* Commandline option of editor: version */
-	 N_("Show version information"), NULL},
-	{NULL, '\0', 0, 0, NULL, NULL, NULL}
+	 N_("Show version information"), NULL },
+	{ NULL, '\0', 0, 0, NULL, NULL, NULL }
 };
 
 int main(int argc, char *argv[])
 {
+	GtkBuilder *builder;
 	gchar *filename;
 	gboolean default_used;
 	GtkWidget *notebook;
-	GtkActionGroup *action_group;
-	GtkUIManager *ui_manager;
-	GtkWidget *vbox;
-	GtkWidget *menubar;
-	GtkAccelGroup *accel_group;
 	GError *error = NULL;
 	gchar *icon_file;
 	GOptionContext *context;
@@ -1864,13 +1787,8 @@ int main(int argc, char *argv[])
 	/* set the UI driver to GTK_Driver, since we're using gtk */
 	set_ui_driver(&GTK_Driver);
 
-#if ENABLE_NLS
-	/* Gtk+ handles the locale, we must bind the translations */
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
-#endif
+	/* Initialize translations */
+	gettext_init();
 
 	context =
 	    /* Long description in the command line: --help */
@@ -1897,32 +1815,14 @@ int main(int argc, char *argv[])
 	else
 		filename = NULL;
 
-	toplevel = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	builder =
+	    gtk_builder_new_from_resource
+	    ("/net/sourceforge/pio/editor/gtk/editor.ui");
+	toplevel = GTK_WIDGET(gtk_builder_get_object(builder, "toplevel"));
+	gtk_builder_connect_signals(builder, toplevel);
 	g_signal_connect(G_OBJECT(toplevel), "delete_event",
 			 G_CALLBACK(exit_cb), NULL);
 
-	action_group = gtk_action_group_new("MenuActions");
-	gtk_action_group_set_translation_domain(action_group, PACKAGE);
-	gtk_action_group_add_actions(action_group, entries,
-				     G_N_ELEMENTS(entries), toplevel);
-	gtk_action_group_add_toggle_actions(action_group, toggle_entries,
-					    G_N_ELEMENTS(toggle_entries),
-					    toplevel);
-
-	ui_manager = gtk_ui_manager_new();
-	gtk_ui_manager_insert_action_group(ui_manager, action_group, 0);
-
-	accel_group = gtk_ui_manager_get_accel_group(ui_manager);
-	gtk_window_add_accel_group(GTK_WINDOW(toplevel), accel_group);
-
-	error = NULL;
-	if (!gtk_ui_manager_add_ui_from_string(ui_manager, ui_description,
-					       -1, &error)) {
-		g_message(_("Building menus failed: %s"), error->message);
-		g_error_free(error);
-		return 1;
-	}
-
 	config_init("pioneers-editor");
 
 	icon_file =
@@ -1938,9 +1838,7 @@ int main(int argc, char *argv[])
 	themes_init();
 	colors_init();
 
-	notebook = gtk_notebook_new();
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
-
+	notebook = GTK_WIDGET(gtk_builder_get_object(builder, "notebook"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), build_map(),
 				 /* Tab page name */
 				 gtk_label_new(_("Map")));
@@ -1957,13 +1855,6 @@ int main(int argc, char *argv[])
 	roll_menu = build_roll_menu();
 	port_menu = build_port_menu();
 
-	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-	gtk_container_add(GTK_CONTAINER(toplevel), vbox);
-
-	menubar = gtk_ui_manager_get_widget(ui_manager, "/MainMenu");
-	gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
-
 	if (filename == NULL) {
 		filename =
 		    config_get_string("editor/last-game", &default_used);
