@@ -11,7 +11,8 @@ static const gchar *building_names[NUM_BUILD_TYPES] = {
 	N_("City"), N_("City wall")
 };
 
-static void game_buildings_init(GameBuildings * gb);
+static void game_buildings_init(GTypeInstance * instance,
+				gpointer g_class);
 
 /* Register the class */
 GType game_buildings_get_type(void)
@@ -28,42 +29,41 @@ GType game_buildings_get_type(void)
 			NULL,	/* class_data */
 			sizeof(GameBuildings),
 			0,
-			(GInstanceInitFunc) game_buildings_init,
+			game_buildings_init,
 			NULL
 		};
 		gb_type =
-		    g_type_register_static(GTK_TYPE_TABLE, "GameBuildings",
+		    g_type_register_static(GTK_TYPE_GRID, "GameBuildings",
 					   &gb_info, 0);
 	}
 	return gb_type;
 }
 
 /* Build the composite widget */
-static void game_buildings_init(GameBuildings * gb)
+static void game_buildings_init(GTypeInstance * instance,
+				G_GNUC_UNUSED gpointer g_class)
 {
 	GtkWidget *label;
 	GtkWidget *spin;
 	GtkAdjustment *adjustment;
-	guint row;
+	gint row;
+	GameBuildings *gb = GAMEBUILDINGS(instance);
 
-	gtk_table_resize(GTK_TABLE(gb), NUM_BUILD_TYPES - 1, 2);
-	gtk_table_set_row_spacings(GTK_TABLE(gb), 3);
-	gtk_table_set_col_spacings(GTK_TABLE(gb), 5);
-	gtk_table_set_homogeneous(GTK_TABLE(gb), TRUE);
+	gtk_grid_set_row_spacing(GTK_GRID(gb), 3);
+	gtk_grid_set_column_spacing(GTK_GRID(gb), 5);
+	gtk_grid_set_column_homogeneous(GTK_GRID(gb), TRUE);
 
 	for (row = 1; row < NUM_BUILD_TYPES; row++) {
 		label = gtk_label_new(gettext(building_names[row]));
-		gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-		gtk_table_attach_defaults(GTK_TABLE(gb), label,
-					  0, 1, row - 1, row);
+		gtk_label_set_xalign(GTK_LABEL(label), 0.0);
+		gtk_grid_attach(GTK_GRID(gb), label, 0, row - 1, 1, 1);
 
 		adjustment =
 		    GTK_ADJUSTMENT(gtk_adjustment_new(0, 0, 100, 1, 5, 0));
 		spin =
 		    gtk_spin_button_new(GTK_ADJUSTMENT(adjustment), 1, 0);
 		gtk_entry_set_alignment(GTK_ENTRY(spin), 1.0);
-		gtk_table_attach_defaults(GTK_TABLE(gb), spin,
-					  1, 2, row - 1, row);
+		gtk_grid_attach(GTK_GRID(gb), spin, 1, row - 1, 1, 1);
 		gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
 		gb->num_buildings[row] = GTK_SPIN_BUTTON(spin);
 	}
