@@ -23,17 +23,14 @@
 #include "config.h"
 #include "version.h"
 
-#ifdef HAVE_LOCALE_H
-#include <locale.h>
-#endif
 #include <ctype.h>
 #include <gtk/gtk.h>
-#include <string.h>
 
 #include "aboutbox.h"
 #include "game.h"
 #include "game-list.h"
 #include "common_gtk.h"
+#include "gettext.h"
 
 #include "config-gnome.h"
 #include "server.h"
@@ -46,7 +43,10 @@
 
 #define MAINICON_FILE	"pioneers-server.png"
 
-static GtkWidget *toplevel;	/* top level window */
+/* Callback functions from the resource file */
+G_MODULE_EXPORT void check_vp_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void quit_cb(GObject * gobject, gpointer user_data);
+G_MODULE_EXPORT void help_about_cb(GObject * gobject, gpointer user_data);
 
 static GtkWidget *settings_notebook;	/* relevant settings */
 
@@ -71,9 +71,6 @@ static gboolean show_version = FALSE;
 
 /* Local function prototypes */
 static void add_game_to_list(gpointer name, gpointer user_data);
-static void check_vp_cb(GObject * caller, gpointer main_window);
-static void quit_cb(void);
-static void help_about_cb(void);
 
 enum {
 	PLAYER_COLUMN_CONNECTED,
@@ -84,48 +81,6 @@ enum {
 	PLAYER_COLUMN_LAST
 };
 
-/* Normal items */
-static GtkActionEntry entries[] = {
-	{"GameMenu", NULL,
-	 /* Menu entry */
-	 N_("_Game"), NULL, NULL, NULL},
-	{"HelpMenu", NULL,
-	 /* Menu entry */
-	 N_("_Help"), NULL, NULL, NULL},
-	{"GameCheckVP", NULL,
-	 /* Menu entry */
-	 N_("_Check Victory Point Target"),
-	 NULL,
-	 /* Tooltop for Check Victory Point Target menu entry */
-	 N_("Check whether the game can be won"), G_CALLBACK(check_vp_cb)},
-	{"GameQuit", NULL,
-	 /* Menu entry */
-	 N_("_Quit"), "<control>Q",
-	 /* Tooltop for Quit menu entry */
-	 N_("Quit the program"), quit_cb},
-	{"HelpAbout", NULL,
-	 /* Menu entry */
-	 N_("_About Pioneers Server"), NULL,
-	 /* Tooltop for About Pioneers Server menu entry */
-	 N_("Information about Pioneers Server"), help_about_cb}
-};
-
-/* *INDENT-OFF* */
-static const char *ui_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='GameMenu'>"
-"      <menuitem action='GameCheckVP' />"
-"      <separator/>"
-"      <menuitem action='GameQuit' />"
-"    </menu>"
-"    <menu action='HelpMenu'>"
-"      <menuitem action='HelpAbout' />"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-/* *INDENT-ON* */
-
 static void port_entry_changed_cb(GtkWidget * widget,
 				  G_GNUC_UNUSED gpointer user_data)
 {
@@ -365,8 +320,8 @@ static void launchclient_clicked_cb(G_GNUC_UNUSED GtkButton * widget,
 	/* Spawn the child. */
 	if (!g_spawn_async(NULL, child_argv, NULL, child_flags,
 			   NULL, NULL, NULL, &error)) {
-		/* Error message when program %1 is started, reason is %2 */
 		log_message(MSG_ERROR,
+			    /* Error message when program %1 is started, reason is %2 */
 			    _("Error starting %s: %s\n"),
 			    child_argv[0], error->message);
 		g_error_free(error);
@@ -526,7 +481,7 @@ static GtkWidget *build_game_rules(void)
  */
 static GtkWidget *build_server_frame(void)
 {
-	/* table */
+	/* grid */
 	/*       server port label */
 	/*        - port entry */
 	/*       register toggle */
@@ -536,7 +491,7 @@ static GtkWidget *build_server_frame(void)
 	/*        - hostname entry */
 	/*       random toggle */
 
-	GtkWidget *table;
+	GtkWidget *grid;
 	GtkWidget *label;
 	GtkWidget *toggle;
 	GtkWidget *port_entry;
@@ -544,28 +499,27 @@ static GtkWidget *build_server_frame(void)
 	gint novar;
 	gchar *metaserver_name;
 
-	/* table */
-	table = gtk_table_new(6, 2, FALSE);
-	gtk_widget_show(table);
-	gtk_container_set_border_width(GTK_CONTAINER(table), 3);
-	gtk_table_set_row_spacings(GTK_TABLE(table), 3);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 5);
+	/* grid */
+	grid = gtk_grid_new();
+	gtk_widget_set_hexpand(grid, FALSE);
+	gtk_widget_show(grid);
+	gtk_container_set_border_width(GTK_CONTAINER(grid), 3);
+	gtk_grid_set_row_spacing(GTK_GRID(grid), 3);
+	gtk_grid_set_column_spacing(GTK_GRID(grid), 5);
 
 	/* server port label */
 	label = gtk_label_new(_("Server port"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(grid), label, 0, 0, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	/* port entry */
 	port_entry = gtk_entry_new();
 	g_signal_connect(G_OBJECT(port_entry), "changed",
 			 G_CALLBACK(port_entry_changed_cb), NULL);
 	gtk_widget_show(port_entry);
-	gtk_table_attach(GTK_TABLE(table), port_entry, 1, 2, 0, 1,
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
-			 0);
+	gtk_widget_set_hexpand(port_entry, TRUE);
+	gtk_grid_attach(GTK_GRID(grid), port_entry, 1, 0, 1, 1);
 	gtk_widget_set_tooltip_text(port_entry,
 				    _("The port for the game server"));
 
@@ -578,9 +532,7 @@ static GtkWidget *build_server_frame(void)
 	/* register_toggle */
 	toggle = gtk_check_button_new_with_label(_("Register server"));
 	gtk_widget_show(toggle);
-	gtk_table_attach(GTK_TABLE(table), toggle, 0, 2, 1, 2,
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
-			 0);
+	gtk_grid_attach(GTK_GRID(grid), toggle, 0, 1, 2, 1);
 	g_signal_connect(G_OBJECT(toggle), "toggled",
 			 G_CALLBACK(register_toggle_cb), NULL);
 	gtk_widget_set_tooltip_text(toggle,
@@ -592,16 +544,13 @@ static GtkWidget *build_server_frame(void)
 	/* metaserver label */
 	label = gtk_label_new(_("Metaserver"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
-			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(grid), label, 0, 2, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	/* meta entry */
 	meta_entry = metaserver_new();
 	gtk_widget_show(meta_entry);
-	gtk_table_attach(GTK_TABLE(table), meta_entry, 1, 2, 2, 3,
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
-			 0);
+	gtk_grid_attach(GTK_GRID(grid), meta_entry, 1, 2, 1, 1);
 	gtk_widget_set_sensitive(meta_entry, register_server);
 
 	/* initialize meta entry */
@@ -617,18 +566,16 @@ static GtkWidget *build_server_frame(void)
 	/* hostname label */
 	label = gtk_label_new(_("Reported hostname"));
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
-			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_grid_attach(GTK_GRID(grid), label, 0, 3, 1, 1);
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 
 	/* hostname entry */
 	overridden_hostname_entry = gtk_entry_new();
 	g_signal_connect(G_OBJECT(overridden_hostname_entry), "changed",
 			 G_CALLBACK(overridden_hostname_changed_cb), NULL);
 	gtk_widget_show(overridden_hostname_entry);
-	gtk_table_attach(GTK_TABLE(table), overridden_hostname_entry, 1, 2,
-			 3, 4, GTK_EXPAND | GTK_FILL,
-			 GTK_EXPAND | GTK_FILL, 0, 0);
+	gtk_grid_attach(GTK_GRID(grid), overridden_hostname_entry, 1, 3, 1,
+			1);
 	gtk_widget_set_tooltip_text(overridden_hostname_entry,
 				    _(""
 				      "The public name of this computer "
@@ -651,9 +598,7 @@ static GtkWidget *build_server_frame(void)
 	/* random toggle */
 	toggle = gtk_check_button_new_with_label(_("Random turn order"));
 	gtk_widget_show(toggle);
-	gtk_table_attach(GTK_TABLE(table), toggle, 0, 2, 4, 5,
-			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
-			 0);
+	gtk_grid_attach(GTK_GRID(grid), toggle, 0, 4, 2, 1);
 	g_signal_connect(G_OBJECT(toggle), "toggled",
 			 G_CALLBACK(random_toggle_cb), NULL);
 	gtk_widget_set_tooltip_text(toggle, _("Randomize turn order"));
@@ -663,7 +608,7 @@ static GtkWidget *build_server_frame(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle),
 				     random_order);
 
-	return table;
+	return grid;
 }
 
 static void
@@ -1091,8 +1036,7 @@ static void load_last_game_params(void)
 	params_free(params);
 }
 
-static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
-			gpointer main_window)
+void check_vp_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
 	GameParams *params;
 
@@ -1135,17 +1079,18 @@ static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
 	    game_rules_get_island_discovery_bonus(GAMERULES(game_rules));
 	update_game_settings(params);
 
-	check_victory_points(params, main_window);
+	check_victory_points(params, GTK_WINDOW(user_data));
 }
 
-static void quit_cb(void)
+void quit_cb(G_GNUC_UNUSED GObject * gobject,
+	     G_GNUC_UNUSED gpointer user_data)
 {
 	gtk_main_quit();
 }
 
-static void help_about_cb(void)
+void help_about_cb(G_GNUC_UNUSED GObject * gobject, gpointer user_data)
 {
-	aboutbox_display(GTK_WINDOW(toplevel),
+	aboutbox_display(GTK_WINDOW(user_data),
 			 /* Caption of about box */
 			 _("About the Pioneers Game Server"));
 }
@@ -1165,23 +1110,21 @@ void request_server_stop(Game * game)
 }
 
 static GOptionEntry commandline_entries[] = {
-	{"debug", '\0', 0, G_OPTION_ARG_NONE, &enable_debug,
+	{ "debug", '\0', 0, G_OPTION_ARG_NONE, &enable_debug,
 	 /* Commandline option of server-gtk: enable debug logging */
-	 N_("Enable debug messages"), NULL},
-	{"version", '\0', 0, G_OPTION_ARG_NONE, &show_version,
+	 N_("Enable debug messages"), NULL },
+	{ "version", '\0', 0, G_OPTION_ARG_NONE, &show_version,
 	 /* Commandline option of server-gtk: version */
-	 N_("Show version information"), NULL},
-	{NULL, '\0', 0, 0, NULL, NULL, NULL}
+	 N_("Show version information"), NULL },
+	{ NULL, '\0', 0, 0, NULL, NULL, NULL }
 };
 
 int main(int argc, char *argv[])
 {
 	gchar *icon_file;
+	GtkWidget *toplevel;
 	GtkWidget *vbox;
-	GtkWidget *menubar;
-	GtkActionGroup *action_group;
-	GtkUIManager *ui_manager;
-	GtkAccelGroup *accel_group;
+	GtkBuilder *builder;
 	GError *error = NULL;
 	GOptionContext *context;
 	Game *game;
@@ -1200,13 +1143,8 @@ int main(int argc, char *argv[])
 	/* Initialize frontend inspecific things */
 	server_init();
 
-#ifdef ENABLE_NLS
-	setlocale(LC_ALL, "");
-	/* Gtk+ handles the locale, we must bind the translations */
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
-#endif
+	/* Initialize translations */
+	gettext_init();
 
 	/* Long description in the commandline for server-gtk: help */
 	context = g_option_context_new(_("- Host a game of Pioneers"));
@@ -1229,34 +1167,13 @@ int main(int argc, char *argv[])
 
 	set_enable_debug(enable_debug);
 
-	prepare_gtk_for_close_button_on_tab();
-
-	toplevel = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	builder =
+	    gtk_builder_new_from_resource
+	    ("/net/sourceforge/pio/server/gtk/server.ui");
+	toplevel = GTK_WIDGET(gtk_builder_get_object(builder, "toplevel"));
 	/* Name in the titlebar of the server */
 	gtk_window_set_title(GTK_WINDOW(toplevel), _("Pioneers Server"));
-
-	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-	gtk_container_add(GTK_CONTAINER(toplevel), vbox);
-
-	action_group = gtk_action_group_new("MenuActions");
-	gtk_action_group_set_translation_domain(action_group, PACKAGE);
-	gtk_action_group_add_actions(action_group, entries,
-				     G_N_ELEMENTS(entries), toplevel);
-
-	ui_manager = gtk_ui_manager_new();
-	gtk_ui_manager_insert_action_group(ui_manager, action_group, 0);
-
-	accel_group = gtk_ui_manager_get_accel_group(ui_manager);
-	gtk_window_add_accel_group(GTK_WINDOW(toplevel), accel_group);
-
-	error = NULL;
-	if (!gtk_ui_manager_add_ui_from_string
-	    (ui_manager, ui_description, -1, &error)) {
-		/* Error message */
-		g_message(_("Building menus failed: %s"), error->message);
-		g_error_free(error);
-		return 1;
-	}
+	gtk_builder_connect_signals(builder, toplevel);
 
 	config_init("pioneers-server");
 
@@ -1270,10 +1187,8 @@ int main(int argc, char *argv[])
 	}
 	g_free(icon_file);
 
-	menubar = gtk_ui_manager_get_widget(ui_manager, "/MainMenu");
-	gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, FALSE, 0);
-
 	game = NULL;
+	vbox = GTK_WIDGET(gtk_builder_get_object(builder, "vbox"));
 	gtk_box_pack_start(GTK_BOX(vbox),
 			   build_interface(GTK_WINDOW(toplevel), &game),
 			   TRUE, TRUE, 0);
