@@ -60,10 +60,10 @@ static void start_reconnect_timer(Game * game)
 	}
 	log_message(MSG_INFO,
 		    /* The connection to the metaserver was lost */
-		    ngettext
-		    ("An attempt to reconnect is scheduled in %u second.\n",
-		     "An attempt to reconnect is scheduled in %u seconds.\n",
-		     reconnect_interval), reconnect_interval);
+		    ngettext(""
+			     "An attempt to reconnect is scheduled in %u second.\n",
+			     "An attempt to reconnect is scheduled in %u seconds.\n",
+			     reconnect_interval), reconnect_interval);
 	reconnect_timer =
 	    g_timeout_add(reconnect_interval * 1000, timed_out, game);
 }
@@ -82,6 +82,10 @@ static gboolean timed_out(gpointer data)
 	log_message(MSG_INFO,
 		    _("Attempting to reconnect to the metaserver.\n"));
 	reconnect_interval *= 2;
+	/* The maximum reconnection time is 24 hours */
+	if (reconnect_interval > 24 * 3600) {
+		reconnect_interval = 24 * 3600;
+	}
 	if (!meta_connect(game)) {
 		start_reconnect_timer(game);
 	}
