@@ -84,7 +84,8 @@ static gint next_free_player_num(Game * game, gboolean force_spectator)
 				skip = 0;
 			}
 			idx = 0;
-			while (player_taken[idx] || skip-- != 0)
+			++skip;
+			while (player_taken[idx] || --skip != 0)
 				++idx;
 			return idx;
 		}
@@ -663,6 +664,9 @@ void player_archive(Player * player)
 		return;
 	}
 
+	/* Mark the player as disconnected */
+	player->disconnected = TRUE;
+
 	/* If the player was in the middle of a trade, pop the state
 	   machine and inform others as necessary */
 	state = sm_current(player->sm);
@@ -693,8 +697,7 @@ void player_archive(Player * player)
 	    || state == (StateFunc) mode_select_pirated)
 		robber_undo(player);
 
-	/* Mark the player as disconnected */
-	player->disconnected = TRUE;
+	/* Inform the metaserver */
 	game->num_players--;
 	meta_report_num_players(game->num_players);
 
